{% extends 'core/page.html' %}
{% load i18n %}
{% load static %}

{% block page %}
    <div align='center'>
        <br><br><br><br><br><br><br>
        <figure>
            <img src="{% static 'MaRDMO/images/MaRDMOLogo.png' %}" alt="Logo of MaRDMO Plugin">
        </figure>
        <br><br><br>
        <p style="color:Black;font-size:40px;font-weight:bold">{{ error }}</p>
    </div>
    <!-- Attribution Section -->
    <div align='center' style="margin-top: 50px; font-size: 14px; color: grey;">
        <p>MaRDMO Logo by <a href="https://www.mardi4nfdi.de/about/mission" target="_blank" style="color: grey;">MaRDI</a>, licensed under <a href="https://creativecommons.org/licenses/by-nc-nd/4.0/" target="_blank" style="color: grey;">CC BY-NC-ND 4.0</a>.</p>
    </div>
{% endblock %}

