[{"locale":"fr"},{"key":"m","mappings":{"default":{"default":"mètres","singular":"mètre","dual":""}},"category":"Length","names":["m"]},{"key":"ft","mappings":{"default":{"default":"pieds","singular":"pied","dual":""}},"category":"Length","names":["ft","ft."]},{"key":"in","mappings":{"default":{"default":"pouces","singular":"pouce","dual":""}},"category":"Length","names":["in","in."]},{"key":"mi","mappings":{"default":{"default":"miles","singular":"mile","dual":""}},"category":"Length","names":["mi","mi."]},{"key":"yd","mappings":{"default":{"default":"yards","singular":"yard","dual":""}},"category":"Length","names":["yd","yd."]}]
