[{"locale":"fr"},{"key":"03D0","mappings":{"default":{"default":"bêta grec"}},"category":"Ll"},{"key":"03D1","mappings":{"default":{"default":"thêta cursif"}},"category":"Ll"},{"key":"03D5","mappings":{"default":{"default":"phi droit"}},"category":"Ll"},{"key":"03D6","mappings":{"default":{"default":"pi cursif"}},"category":"Ll"},{"key":"03D7","mappings":{"default":{"default":"ligature kai"}},"category":"Ll"},{"key":"03F0","mappings":{"default":{"default":"kappa cursif"}},"category":"Ll"},{"key":"03F1","mappings":{"default":{"default":"rho à queue"}},"category":"Ll"},{"key":"03F5","mappings":{"default":{"default":"epsilon"}},"category":"Ll"},{"key":"03F6","mappings":{"default":{"default":"epsilon lunaire réfléchi"}},"category":"Sm"},{"key":"03F4","mappings":{"default":{"default":"Thêta majuscule"}},"category":"Lu"},{"key":"1D6B9","mappings":{"default":{"default":"Thêta majuscule en grasse"}},"category":"Lu"},{"key":"1D6F3","mappings":{"default":{"default":"Thêta majuscule en italique"}},"category":"Lu"},{"key":"1D767","mappings":{"default":{"default":"Thêta majuscule en sans empattement grasse"}},"category":"Lu"},{"key":"1D6C1","mappings":{"default":{"default":"symbole mathématique gras nabla"}},"category":"Sm"},{"key":"1D6DB","mappings":{"default":{"default":"symbole mathématique gras dérivée partielle"}},"category":"Sm"},{"key":"1D6DC","mappings":{"default":{"default":"symbole mathématique gras epsilon"}},"category":"Ll"},{"key":"1D6DD","mappings":{"default":{"default":"symbole mathématique gras thêta"}},"category":"Ll"},{"key":"1D6DE","mappings":{"default":{"default":"symbole mathématique gras kappa"}},"category":"Ll"},{"key":"1D6DF","mappings":{"default":{"default":"symbole mathématique gras phi"}},"category":"Ll"},{"key":"1D6E0","mappings":{"default":{"default":"symbole mathématique gras rhô"}},"category":"Ll"},{"key":"1D6E1","mappings":{"default":{"default":"symbole mathématique gras pi"}},"category":"Ll"},{"key":"1D6FB","mappings":{"default":{"default":"symbole mathématique italique nabla"}},"category":"Sm"},{"key":"1D715","mappings":{"default":{"default":"symbole mathématique italique dérivée partielle"}},"category":"Sm"},{"key":"1D716","mappings":{"default":{"default":"symbole mathématique italique epsilon"}},"category":"Ll"},{"key":"1D717","mappings":{"default":{"default":"symbole mathématique italique thêta"}},"category":"Ll"},{"key":"1D718","mappings":{"default":{"default":"symbole mathématique italique kappa"}},"category":"Ll"},{"key":"1D719","mappings":{"default":{"default":"symbole mathématique italique phi"}},"category":"Ll"},{"key":"1D71A","mappings":{"default":{"default":"symbole mathématique italique rhô"}},"category":"Ll"},{"key":"1D71B","mappings":{"default":{"default":"symbole mathématique italique pi"}},"category":"Ll"},{"key":"1D76F","mappings":{"default":{"default":"symbole mathématique gras sans empattement nabla"}},"category":"Sm"},{"key":"1D789","mappings":{"default":{"default":"symbole mathématique gras sans empattement dérivée partielle"}},"category":"Sm"},{"key":"1D78A","mappings":{"default":{"default":"symbole mathématique gras sans empattement epsilon"}},"category":"Ll"},{"key":"1D78B","mappings":{"default":{"default":"symbole mathématique gras sans empattement thêta"}},"category":"Ll"},{"key":"1D78C","mappings":{"default":{"default":"symbole mathématique gras sans empattement kappa"}},"category":"Ll"},{"key":"1D78D","mappings":{"default":{"default":"symbole mathématique gras sans empattement phi"}},"category":"Ll"},{"key":"1D78E","mappings":{"default":{"default":"symbole mathématique gras sans empattement rhô"}},"category":"Ll"},{"key":"1D78F","mappings":{"default":{"default":"symbole mathématique gras sans empattement pi"}},"category":"Ll"}]
