[{"locale":"nemeth"},{"category":"Algebra","mappings":{"default":{"default":"⠙⠑⠛"}},"key":"deg","names":["deg"]},{"category":"Algebra","mappings":{"default":{"default":"⠙⠑⠞"}},"key":"det","names":["det"]},{"category":"Algebra","mappings":{"default":{"default":"⠙⠊⠍"}},"key":"dim","names":["dim"]},{"category":"Algebra","mappings":{"default":{"default":"⠓⠕⠍"}},"key":"hom","names":["hom","Hom"]},{"category":"Algebra","mappings":{"default":{"default":"⠅⠑⠗"}},"key":"ker","names":["ker"]},{"category":"Algebra","mappings":{"default":{"default":"⠠⠞⠗"}},"key":"Tr","names":["Tr","tr"]}]
