[{"locale":"es"},{"key":"F","names":["F","F.","°F"],"mappings":{"default":{"default":"Fahrenheit"}},"category":"temperature"},{"key":"C","names":["C","°C"],"mappings":{"default":{"default":"centígrados"}},"category":"temperature"},{"key":"K","names":["K","°K"],"mappings":{"default":{"default":"Kelvin"}},"category":"temperature"}]
