[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠁"}},"key":"1D434"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠃"}},"key":"1D435"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠉"}},"key":"1D436"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠙"}},"key":"1D437"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠑"}},"key":"1D438"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠋"}},"key":"1D439"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠛"}},"key":"1D43A"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠓"}},"key":"1D43B"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠊"}},"key":"1D43C"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠚"}},"key":"1D43D"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠅"}},"key":"1D43E"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠇"}},"key":"1D43F"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠍"}},"key":"1D440"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠝"}},"key":"1D441"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠕"}},"key":"1D442"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠏"}},"key":"1D443"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠟"}},"key":"1D444"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠗"}},"key":"1D445"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠎"}},"key":"1D446"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠞"}},"key":"1D447"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠥"}},"key":"1D448"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠧"}},"key":"1D449"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠺"}},"key":"1D44A"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠭"}},"key":"1D44B"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠽"}},"key":"1D44C"},{"category":"Lu","mappings":{"default":{"default":"⠨⠠⠵"}},"key":"1D44D"},{"category":"Ll","mappings":{"default":{"default":"⠨⠁"}},"key":"1D44E"},{"category":"Ll","mappings":{"default":{"default":"⠨⠃"}},"key":"1D44F"},{"category":"Ll","mappings":{"default":{"default":"⠨⠉"}},"key":"1D450"},{"category":"Ll","mappings":{"default":{"default":"⠨⠙"}},"key":"1D451"},{"category":"Ll","mappings":{"default":{"default":"⠨⠑"}},"key":"1D452"},{"category":"Ll","mappings":{"default":{"default":"⠨⠋"}},"key":"1D453"},{"category":"Ll","mappings":{"default":{"default":"⠨⠛"}},"key":"1D454"},{"category":"Ll","mappings":{"default":{"default":"⠨⠓"}},"key":"210E"},{"category":"Ll","mappings":{"default":{"default":"⠨⠊"}},"key":"1D456"},{"category":"Ll","mappings":{"default":{"default":"⠨⠚"}},"key":"1D457"},{"category":"Ll","mappings":{"default":{"default":"⠨⠅"}},"key":"1D458"},{"category":"Ll","mappings":{"default":{"default":"⠨⠇"}},"key":"1D459"},{"category":"Ll","mappings":{"default":{"default":"⠨⠍"}},"key":"1D45A"},{"category":"Ll","mappings":{"default":{"default":"⠨⠝"}},"key":"1D45B"},{"category":"Ll","mappings":{"default":{"default":"⠨⠕"}},"key":"1D45C"},{"category":"Ll","mappings":{"default":{"default":"⠨⠏"}},"key":"1D45D"},{"category":"Ll","mappings":{"default":{"default":"⠨⠟"}},"key":"1D45E"},{"category":"Ll","mappings":{"default":{"default":"⠨⠗"}},"key":"1D45F"},{"category":"Ll","mappings":{"default":{"default":"⠨⠎"}},"key":"1D460"},{"category":"Ll","mappings":{"default":{"default":"⠨⠞"}},"key":"1D461"},{"category":"Ll","mappings":{"default":{"default":"⠨⠥"}},"key":"1D462"},{"category":"Ll","mappings":{"default":{"default":"⠨⠧"}},"key":"1D463"},{"category":"Ll","mappings":{"default":{"default":"⠨⠺"}},"key":"1D464"},{"category":"Ll","mappings":{"default":{"default":"⠨⠭"}},"key":"1D465"},{"category":"Ll","mappings":{"default":{"default":"⠨⠽"}},"key":"1D466"},{"category":"Ll","mappings":{"default":{"default":"⠨⠵"}},"key":"1D467"}]
