[{"locale":"fr"},{"key":"1D400","mappings":{"default":{"default":"A majuscule en gras"}},"category":"Lu"},{"key":"1D401","mappings":{"default":{"default":"B majuscule en gras"}},"category":"Lu"},{"key":"1D402","mappings":{"default":{"default":"C majuscule en gras"}},"category":"Lu"},{"key":"1D403","mappings":{"default":{"default":"D majuscule en gras"}},"category":"Lu"},{"key":"1D404","mappings":{"default":{"default":"E majuscule en gras"}},"category":"Lu"},{"key":"1D405","mappings":{"default":{"default":"F majuscule en gras"}},"category":"Lu"},{"key":"1D406","mappings":{"default":{"default":"G majuscule en gras"}},"category":"Lu"},{"key":"1D407","mappings":{"default":{"default":"H majuscule en gras"}},"category":"Lu"},{"key":"1D408","mappings":{"default":{"default":"I majuscule en gras"}},"category":"Lu"},{"key":"1D409","mappings":{"default":{"default":"J majuscule en gras"}},"category":"Lu"},{"key":"1D40A","mappings":{"default":{"default":"K majuscule en gras"}},"category":"Lu"},{"key":"1D40B","mappings":{"default":{"default":"L majuscule en gras"}},"category":"Lu"},{"key":"1D40C","mappings":{"default":{"default":"M majuscule en gras"}},"category":"Lu"},{"key":"1D40D","mappings":{"default":{"default":"N majuscule en gras"}},"category":"Lu"},{"key":"1D40E","mappings":{"default":{"default":"O majuscule en gras"}},"category":"Lu"},{"key":"1D40F","mappings":{"default":{"default":"P majuscule en gras"}},"category":"Lu"},{"key":"1D410","mappings":{"default":{"default":"Q majuscule en gras"}},"category":"Lu"},{"key":"1D411","mappings":{"default":{"default":"R majuscule en gras"}},"category":"Lu"},{"key":"1D412","mappings":{"default":{"default":"S majuscule en gras"}},"category":"Lu"},{"key":"1D413","mappings":{"default":{"default":"T majuscule en gras"}},"category":"Lu"},{"key":"1D414","mappings":{"default":{"default":"U majuscule en gras"}},"category":"Lu"},{"key":"1D415","mappings":{"default":{"default":"V majuscule en gras"}},"category":"Lu"},{"key":"1D416","mappings":{"default":{"default":"W majuscule en gras"}},"category":"Lu"},{"key":"1D417","mappings":{"default":{"default":"X majuscule en gras"}},"category":"Lu"},{"key":"1D418","mappings":{"default":{"default":"Y majuscule en gras"}},"category":"Lu"},{"key":"1D419","mappings":{"default":{"default":"Z majuscule en gras"}},"category":"Lu"},{"key":"1D41A","mappings":{"default":{"default":"a en gras"}},"category":"Ll"},{"key":"1D41B","mappings":{"default":{"default":"b en gras"}},"category":"Ll"},{"key":"1D41C","mappings":{"default":{"default":"c en gras"}},"category":"Ll"},{"key":"1D41D","mappings":{"default":{"default":"c en gras"}},"category":"Ll"},{"key":"1D41E","mappings":{"default":{"default":"e en gras"}},"category":"Ll"},{"key":"1D41F","mappings":{"default":{"default":"f en gras"}},"category":"Ll"},{"key":"1D420","mappings":{"default":{"default":"g en gras"}},"category":"Ll"},{"key":"1D421","mappings":{"default":{"default":"h en gras"}},"category":"Ll"},{"key":"1D422","mappings":{"default":{"default":"i en gras"}},"category":"Ll"},{"key":"1D423","mappings":{"default":{"default":"j en gras"}},"category":"Ll"},{"key":"1D424","mappings":{"default":{"default":"k en gras"}},"category":"Ll"},{"key":"1D425","mappings":{"default":{"default":"l en gras"}},"category":"Ll"},{"key":"1D426","mappings":{"default":{"default":"m en gras"}},"category":"Ll"},{"key":"1D427","mappings":{"default":{"default":"n en gras"}},"category":"Ll"},{"key":"1D428","mappings":{"default":{"default":"o en gras"}},"category":"Ll"},{"key":"1D429","mappings":{"default":{"default":"p en gras"}},"category":"Ll"},{"key":"1D42A","mappings":{"default":{"default":"q en gras"}},"category":"Ll"},{"key":"1D42B","mappings":{"default":{"default":"r en gras"}},"category":"Ll"},{"key":"1D42C","mappings":{"default":{"default":"s en gras"}},"category":"Ll"},{"key":"1D42D","mappings":{"default":{"default":"t en gras"}},"category":"Ll"},{"key":"1D42E","mappings":{"default":{"default":"u en gras"}},"category":"Ll"},{"key":"1D42F","mappings":{"default":{"default":"v en gras"}},"category":"Ll"},{"key":"1D430","mappings":{"default":{"default":"w en gras"}},"category":"Ll"},{"key":"1D431","mappings":{"default":{"default":"x en gras"}},"category":"Ll"},{"key":"1D432","mappings":{"default":{"default":"y en gras"}},"category":"Ll"},{"key":"1D433","mappings":{"default":{"default":"z en gras"}},"category":"Ll"}]
