[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠁"}},"key":"1D49C"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠃"}},"key":"212C"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠉"}},"key":"1D49E"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠙"}},"key":"1D49F"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠑"}},"key":"2130"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠋"}},"key":"2131"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠛"}},"key":"1D4A2"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠓"}},"key":"210B"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠊"}},"key":"2110"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠚"}},"key":"1D4A5"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠅"}},"key":"1D4A6"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠇"}},"key":"2112"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠍"}},"key":"2133"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠝"}},"key":"1D4A9"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠕"}},"key":"1D4AA"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠏"}},"key":"1D4AB"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠟"}},"key":"1D4AC"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠗"}},"key":"211B"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠎"}},"key":"1D4AE"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠞"}},"key":"1D4AF"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠥"}},"key":"1D4B0"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠧"}},"key":"1D4B1"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠺"}},"key":"1D4B2"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠭"}},"key":"1D4B3"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠽"}},"key":"1D4B4"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠵"}},"key":"1D4B5"},{"category":"Ll","mappings":{"default":{"default":"⠈⠁"}},"key":"1D4B6"},{"category":"Ll","mappings":{"default":{"default":"⠈⠃"}},"key":"1D4B7"},{"category":"Ll","mappings":{"default":{"default":"⠈⠉"}},"key":"1D4B8"},{"category":"Ll","mappings":{"default":{"default":"⠈⠙"}},"key":"1D4B9"},{"category":"Ll","mappings":{"default":{"default":"⠈⠑"}},"key":"212F"},{"category":"Ll","mappings":{"default":{"default":"⠈⠋"}},"key":"1D4BB"},{"category":"Ll","mappings":{"default":{"default":"⠈⠛"}},"key":"210A"},{"category":"Ll","mappings":{"default":{"default":"⠈⠓"}},"key":"1D4BD"},{"category":"Ll","mappings":{"default":{"default":"⠈⠊"}},"key":"1D4BE"},{"category":"Ll","mappings":{"default":{"default":"⠈⠚"}},"key":"1D4BF"},{"category":"Ll","mappings":{"default":{"default":"⠈⠅"}},"key":"1D4C0"},{"category":"Ll","mappings":{"default":{"default":"⠈⠇"}},"key":"1D4C1"},{"category":"Ll","mappings":{"default":{"default":"⠈⠍"}},"key":"1D4C2"},{"category":"Ll","mappings":{"default":{"default":"⠈⠝"}},"key":"1D4C3"},{"category":"Ll","mappings":{"default":{"default":"⠈⠕"}},"key":"2134"},{"category":"Ll","mappings":{"default":{"default":"⠈⠏"}},"key":"1D4C5"},{"category":"Ll","mappings":{"default":{"default":"⠈⠟"}},"key":"1D4C6"},{"category":"Ll","mappings":{"default":{"default":"⠈⠗"}},"key":"1D4C7"},{"category":"Ll","mappings":{"default":{"default":"⠈⠎"}},"key":"1D4C8"},{"category":"Ll","mappings":{"default":{"default":"⠈⠞"}},"key":"1D4C9"},{"category":"Ll","mappings":{"default":{"default":"⠈⠥"}},"key":"1D4CA"},{"category":"Ll","mappings":{"default":{"default":"⠈⠧"}},"key":"1D4CB"},{"category":"Ll","mappings":{"default":{"default":"⠈⠺"}},"key":"1D4CC"},{"category":"Ll","mappings":{"default":{"default":"⠈⠭"}},"key":"1D4CD"},{"category":"Ll","mappings":{"default":{"default":"⠈⠽"}},"key":"1D4CE"},{"category":"Ll","mappings":{"default":{"default":"⠈⠵"}},"key":"1D4CF"}]
