[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula A"}},"key":"1D468"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula B"}},"key":"1D469"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula C"}},"key":"1D46A"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula D"}},"key":"1D46B"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula E"}},"key":"1D46C"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula F"}},"key":"1D46D"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula G"}},"key":"1D46E"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula H"}},"key":"1D46F"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula I"}},"key":"1D470"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula J"}},"key":"1D471"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula K"}},"key":"1D472"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula L"}},"key":"1D473"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula M"}},"key":"1D474"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula N"}},"key":"1D475"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula O"}},"key":"1D476"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula P"}},"key":"1D477"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Q"}},"key":"1D478"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula R"}},"key":"1D479"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula S"}},"key":"1D47A"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula T"}},"key":"1D47B"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula U"}},"key":"1D47C"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula V"}},"key":"1D47D"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula W"}},"key":"1D47E"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula X"}},"key":"1D47F"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Y"}},"key":"1D480"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Z"}},"key":"1D481"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva a"}},"key":"1D482"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva b"}},"key":"1D483"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva c"}},"key":"1D484"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva d"}},"key":"1D485"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva e"}},"key":"1D486"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva f"}},"key":"1D487"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva g"}},"key":"1D488"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva h"}},"key":"1D489"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva i"}},"key":"1D48A"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva j"}},"key":"1D48B"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva k"}},"key":"1D48C"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva l"}},"key":"1D48D"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva m"}},"key":"1D48E"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva n"}},"key":"1D48F"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva o"}},"key":"1D490"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva p"}},"key":"1D491"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva q"}},"key":"1D492"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva r"}},"key":"1D493"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva s"}},"key":"1D494"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva t"}},"key":"1D495"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva u"}},"key":"1D496"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva v"}},"key":"1D497"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva w"}},"key":"1D498"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva x"}},"key":"1D499"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva y"}},"key":"1D49A"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva z"}},"key":"1D49B"}]
