{% extends 'core/page.html' %}
{% load i18n %}
{% load core_tags %}

{% block page %}

    {% include include_file with title=include_params.title%}
    <br>
    <br>
    <br>
    {% bootstrap_form submit=_('Export to MaRDI Service') %}

{% endblock %}
