[{"locale":"fr"},{"key":"log","mappings":{"default":{"default":"log"}},"category":"Logarithm","names":["log"]},{"key":"ln","mappings":{"default":{"default":"logarithme népérien"}},"category":"Logarithm","names":["ln"]},{"key":"lim","mappings":{"default":{"default":"limite"}},"category":"Limits","names":["lim"]}]
