[{"locale":"nemeth"},{"category":"energy","mappings":{"default":{"default":"⠠⠺"}},"key":"W","names":["W","w"]},{"category":"energy","mappings":{"default":{"default":"⠅⠠⠺"}},"key":"kW","names":["kw","kW"]},{"category":"energy","mappings":{"default":{"default":"⠍⠠⠺"}},"key":"mW","names":["mw","mW"]},{"category":"energy","mappings":{"default":{"default":"⠅⠺⠓"}},"key":"kwh","names":["kwh","kWh"]},{"category":"energy","mappings":{"default":{"default":"⠠⠚"}},"key":"J","names":["J"]},{"category":"energy","mappings":{"default":{"default":"⠠⠝"}},"key":"N","names":["N"]},{"category":"energy","mappings":{"default":{"default":"⠠⠁"}},"key":"A","names":["A"]},{"category":"energy","mappings":{"default":{"default":"⠠⠧"}},"key":"V","names":["V"]},{"category":"energy","mappings":{"default":{"default":"⠨⠍⠨⠠⠺"}},"key":"µΩ","names":["µΩ"]},{"category":"energy","mappings":{"default":{"default":"⠍⠨⠠⠺"}},"key":"mΩ","names":["mΩ"]},{"category":"energy","mappings":{"default":{"default":"⠨⠠⠺"}},"key":"Ω","names":["Ω","Ohm"]},{"category":"energy","mappings":{"default":{"default":"⠅⠨⠠⠺"}},"key":"kΩ","names":["kΩ","KΩ"]},{"category":"energy","mappings":{"default":{"default":"⠨⠠⠺"}},"key":"Ω","names":["Ω"]},{"category":"energy","mappings":{"default":{"default":"⠍⠨⠠⠺"}},"key":"MΩ","names":["MΩ"]},{"category":"energy","mappings":{"default":{"default":"⠛⠨⠠⠺"}},"key":"GΩ","names":["GΩ"]}]
