[{"locale":"nemeth"},{"category":"","mappings":{"default":{"default":"⠃"}},"key":"b","names":["b"]},{"category":"","mappings":{"default":{"default":"⠠⠃"}},"key":"B","names":["B"]},{"category":"","mappings":{"default":{"default":"⠅⠃"}},"key":"KB","names":["KB"]},{"category":"","mappings":{"default":{"default":"⠍⠃"}},"key":"MB","names":["MB"]},{"category":"","mappings":{"default":{"default":"⠛⠃"}},"key":"GB","names":["GB"]},{"category":"","mappings":{"default":{"default":"⠞⠃"}},"key":"TB","names":["TB"]}]
