[{"locale":"fr"},{"key":"1D538","mappings":{"default":{"default":"A majuscule ajouré"}},"category":"Lu"},{"key":"1D539","mappings":{"default":{"default":"B majuscule ajouré"}},"category":"Lu"},{"key":"2102","mappings":{"default":{"default":"C majuscule ajouré"}},"category":"Lu"},{"key":"1D53B","mappings":{"default":{"default":"D majuscule ajouré"}},"category":"Lu"},{"key":"1D53C","mappings":{"default":{"default":"E majuscule ajouré"}},"category":"Lu"},{"key":"1D53D","mappings":{"default":{"default":"F majuscule ajouré"}},"category":"Lu"},{"key":"1D53E","mappings":{"default":{"default":"G majuscule ajouré"}},"category":"Lu"},{"key":"210D","mappings":{"default":{"default":"H majuscule ajouré"}},"category":"Lu"},{"key":"1D540","mappings":{"default":{"default":"I majuscule ajouré"}},"category":"Lu"},{"key":"1D541","mappings":{"default":{"default":"J majuscule ajouré"}},"category":"Lu"},{"key":"1D542","mappings":{"default":{"default":"K majuscule ajouré"}},"category":"Lu"},{"key":"1D543","mappings":{"default":{"default":"L majuscule ajouré"}},"category":"Lu"},{"key":"1D544","mappings":{"default":{"default":"M majuscule ajouré"}},"category":"Lu"},{"key":"2115","mappings":{"default":{"default":"N majuscule ajouré"}},"category":"Lu"},{"key":"1D546","mappings":{"default":{"default":"O majuscule ajouré"}},"category":"Lu"},{"key":"2119","mappings":{"default":{"default":"P majuscule ajouré"}},"category":"Lu"},{"key":"211A","mappings":{"default":{"default":"Q majuscule ajouré"}},"category":"Lu"},{"key":"211D","mappings":{"default":{"default":"R majuscule ajouré"}},"category":"Lu"},{"key":"1D54A","mappings":{"default":{"default":"S majuscule ajouré"}},"category":"Lu"},{"key":"1D54B","mappings":{"default":{"default":"T majuscule ajouré"}},"category":"Lu"},{"key":"1D54C","mappings":{"default":{"default":"U majuscule ajouré"}},"category":"Lu"},{"key":"1D54D","mappings":{"default":{"default":"V majuscule ajouré"}},"category":"Lu"},{"key":"1D54E","mappings":{"default":{"default":"W majuscule ajouré"}},"category":"Lu"},{"key":"1D54F","mappings":{"default":{"default":"X majuscule ajouré"}},"category":"Lu"},{"key":"1D550","mappings":{"default":{"default":"Y majuscule ajouré"}},"category":"Lu"},{"key":"2124","mappings":{"default":{"default":"Z majuscule ajouré"}},"category":"Lu"},{"key":"1D552","mappings":{"default":{"default":"a ajouré"}},"category":"Ll"},{"key":"1D553","mappings":{"default":{"default":"b ajouré"}},"category":"Ll"},{"key":"1D554","mappings":{"default":{"default":"c ajouré"}},"category":"Ll"},{"key":"1D555","mappings":{"default":{"default":"d ajouré"}},"category":"Ll"},{"key":"1D556","mappings":{"default":{"default":"e ajouré"}},"category":"Ll"},{"key":"1D557","mappings":{"default":{"default":"f ajouré"}},"category":"Ll"},{"key":"1D558","mappings":{"default":{"default":"g ajouré"}},"category":"Ll"},{"key":"1D559","mappings":{"default":{"default":"h ajouré"}},"category":"Ll"},{"key":"1D55A","mappings":{"default":{"default":"i ajouré"}},"category":"Ll"},{"key":"1D55B","mappings":{"default":{"default":"j ajouré"}},"category":"Ll"},{"key":"1D55C","mappings":{"default":{"default":"k ajouré"}},"category":"Ll"},{"key":"1D55D","mappings":{"default":{"default":"l ajouré"}},"category":"Ll"},{"key":"1D55E","mappings":{"default":{"default":"m ajouré"}},"category":"Ll"},{"key":"1D55F","mappings":{"default":{"default":"n ajouré"}},"category":"Ll"},{"key":"1D560","mappings":{"default":{"default":"o ajouré"}},"category":"Ll"},{"key":"1D561","mappings":{"default":{"default":"p ajouré"}},"category":"Ll"},{"key":"1D562","mappings":{"default":{"default":"q ajouré"}},"category":"Ll"},{"key":"1D563","mappings":{"default":{"default":"r ajouré"}},"category":"Ll"},{"key":"1D564","mappings":{"default":{"default":"s ajouré"}},"category":"Ll"},{"key":"1D565","mappings":{"default":{"default":"t ajouré"}},"category":"Ll"},{"key":"1D566","mappings":{"default":{"default":"u ajouré"}},"category":"Ll"},{"key":"1D567","mappings":{"default":{"default":"v ajouré"}},"category":"Ll"},{"key":"1D568","mappings":{"default":{"default":"w ajouré"}},"category":"Ll"},{"key":"1D569","mappings":{"default":{"default":"x ajouré"}},"category":"Ll"},{"key":"1D56A","mappings":{"default":{"default":"y ajouré"}},"category":"Ll"},{"key":"1D56B","mappings":{"default":{"default":"z ajouré"}},"category":"Ll"}]
