[{"locale":"fr"},{"key":"210F","mappings":{"default":{"default":"constante de planck sur deux pi"}},"category":"Ll"},{"key":"2116","mappings":{"default":{"default":"symbole numéro"}},"category":"So"},{"key":"2117","mappings":{"default":{"default":"copyright de programme sonore"}},"category":"So"},{"key":"211E","mappings":{"default":{"default":"ordonnances"}},"category":"So"},{"key":"2122","mappings":{"default":{"default":"symbole anglais marque de commerce"}},"category":"So"},{"key":"2125","mappings":{"default":{"default":"symbole once"}},"category":"So"},{"key":"2126","mappings":{"default":{"default":"ohm"}},"category":"Lu"},{"key":"2127","mappings":{"default":{"default":"ohm culbuté"}},"category":"So"},{"key":"212A","mappings":{"default":{"default":"degré kelvin"}},"category":"Lu"},{"key":"212B","mappings":{"default":{"default":"angstroms"}},"category":"Lu"},{"key":"2132","mappings":{"default":{"default":"f culbuté majuscule"}},"category":"Lu"}]
