[{"locale":"es"},{"key":"b","names":["b"],"mappings":{"default":{"default":"bit"}},"category":"memory"},{"key":"B","names":["B"],"mappings":{"default":{"default":"byte"}},"category":"memory"},{"key":"KB","names":["KB"],"mappings":{"default":{"default":"kilobyte"}},"category":"memory"},{"key":"MB","names":["MB"],"mappings":{"default":{"default":"megabyte"}},"category":"memory"},{"key":"GB","names":["GB"],"mappings":{"default":{"default":"gigabyte"}},"category":"memory"},{"key":"TB","names":["TB"],"mappings":{"default":{"default":"terabyte"}},"category":"memory"}]
