[{"locale":"fr"},{"key":"W","mappings":{"default":{"default":"watts","singular":"watt","dual":""}},"category":"energy","names":["W","w"]},{"key":"J","mappings":{"default":{"default":"joules","singular":"joule","dual":""}},"category":"energy","names":["J"]},{"key":"N","mappings":{"default":{"default":"newtons","singular":"newton","dual":""}},"category":"energy","names":["N"]},{"key":"A","mappings":{"default":{"default":"ampères","singular":"ampère","dual":""}},"category":"energy","names":["A"]},{"key":"V","mappings":{"default":{"default":"volts","singular":"volt","dual":""}},"category":"energy","names":["V"]},{"key":"Ω","mappings":{"default":{"default":"ohms","singular":"ohm","dual":""}},"category":"energy","names":["Ω","Ohm"]}]
