[{"locale":"en"},{"category":"memory","mappings":{"default":{"default":"bit"}},"key":"b","names":["b"]},{"category":"memory","mappings":{"default":{"default":"byte"}},"key":"B","names":["B"]},{"category":"memory","mappings":{"default":{"default":"kilobyte"}},"key":"KB","names":["KB"]},{"category":"memory","mappings":{"default":{"default":"megabyte"}},"key":"MB","names":["MB"]},{"category":"memory","mappings":{"default":{"default":"gigabyte"}},"key":"GB","names":["GB"]},{"category":"memory","mappings":{"default":{"default":"terabyte"}},"key":"TB","names":["TB"]}]
