[{"locale":"fr"},{"key":"lb","mappings":{"default":{"default":"livres","singular":"livre","dual":""}},"names":["lb","lb."]},{"key":"oz","mappings":{"default":{"default":"onces","singular":"oce","dual":""}},"names":["oz","oz."]},{"key":"gr","mappings":{"default":{"default":"grains","singular":"grain","dual":""}},"names":["g","gr"]},{"key":"t","mappings":{"default":{"default":"tonnes","singular":"tonne","dual":""}},"names":["t","T"]}]
