[{"locale":"en"},{"category":"weight","mappings":{"default":{"default":"pound"}},"key":"lb","names":["lb","lb."]},{"category":"weight","mappings":{"default":{"default":"long ton"}},"key":"LT","names":["LT","L.T."]},{"category":"weight","mappings":{"default":{"default":"ounce"}},"key":"oz","names":["oz","oz."]},{"category":"weight","mappings":{"default":{"default":"gram"}},"key":"gr","names":["g","gr"]},{"category":"weight","mappings":{"default":{"default":"kilogram"}},"key":"kg","names":["kg"]},{"category":"weight","mappings":{"default":{"default":"microgram"}},"key":"mcg","names":["mcg","µg"]},{"category":"weight","mappings":{"default":{"default":"milligram"}},"key":"mg","names":["mg"]},{"category":"weight","mappings":{"default":{"default":"ton"}},"key":"t","names":["t","T"]}]
