[{"locale":"fr"},{"key":"1D504","mappings":{"default":{"default":"A majuscule en gothique"}},"category":"Lu"},{"key":"1D505","mappings":{"default":{"default":"B majuscule en gothique"}},"category":"Lu"},{"key":"212D","mappings":{"default":{"default":"C majuscule en gothique"}},"category":"Lu"},{"key":"1D507","mappings":{"default":{"default":"D majuscule en gothique"}},"category":"Lu"},{"key":"1D508","mappings":{"default":{"default":"E majuscule en gothique"}},"category":"Lu"},{"key":"1D509","mappings":{"default":{"default":"F majuscule en gothique"}},"category":"Lu"},{"key":"1D50A","mappings":{"default":{"default":"G majuscule en gothique"}},"category":"Lu"},{"key":"210C","mappings":{"default":{"default":"H majuscule en gothique"}},"category":"Lu"},{"key":"2111","mappings":{"default":{"default":"I majuscule en gothique"}},"category":"Lu"},{"key":"1D50D","mappings":{"default":{"default":"J majuscule en gothique"}},"category":"Lu"},{"key":"1D50E","mappings":{"default":{"default":"K majuscule en gothique"}},"category":"Lu"},{"key":"1D50F","mappings":{"default":{"default":"L majuscule en gothique"}},"category":"Lu"},{"key":"1D510","mappings":{"default":{"default":"M majuscule en gothique"}},"category":"Lu"},{"key":"1D511","mappings":{"default":{"default":"N majuscule en gothique"}},"category":"Lu"},{"key":"1D512","mappings":{"default":{"default":"O majuscule en gothique"}},"category":"Lu"},{"key":"1D513","mappings":{"default":{"default":"P majuscule en gothique"}},"category":"Lu"},{"key":"1D514","mappings":{"default":{"default":"Q majuscule en gothique"}},"category":"Lu"},{"key":"211C","mappings":{"default":{"default":"R majuscule en gothique"}},"category":"Lu"},{"key":"1D516","mappings":{"default":{"default":"S majuscule en gothique"}},"category":"Lu"},{"key":"1D517","mappings":{"default":{"default":"T majuscule en gothique"}},"category":"Lu"},{"key":"1D518","mappings":{"default":{"default":"U majuscule en gothique"}},"category":"Lu"},{"key":"1D519","mappings":{"default":{"default":"V majuscule en gothique"}},"category":"Lu"},{"key":"1D51A","mappings":{"default":{"default":"W majuscule en gothique"}},"category":"Lu"},{"key":"1D51B","mappings":{"default":{"default":"X majuscule en gothique"}},"category":"Lu"},{"key":"1D51C","mappings":{"default":{"default":"Y majuscule en gothique"}},"category":"Lu"},{"key":"2128","mappings":{"default":{"default":"Z majuscule en gothique"}},"category":"Lu"},{"key":"1D51E","mappings":{"default":{"default":"a en gothique"}},"category":"Ll"},{"key":"1D51F","mappings":{"default":{"default":"b en gothique"}},"category":"Ll"},{"key":"1D520","mappings":{"default":{"default":"c en gothique"}},"category":"Ll"},{"key":"1D521","mappings":{"default":{"default":"d en gothique"}},"category":"Ll"},{"key":"1D522","mappings":{"default":{"default":"e en gothique"}},"category":"Ll"},{"key":"1D523","mappings":{"default":{"default":"f en gothique"}},"category":"Ll"},{"key":"1D524","mappings":{"default":{"default":"g en gothique"}},"category":"Ll"},{"key":"1D525","mappings":{"default":{"default":"h en gothique"}},"category":"Ll"},{"key":"1D526","mappings":{"default":{"default":"i en gothique"}},"category":"Ll"},{"key":"1D527","mappings":{"default":{"default":"j en gothique"}},"category":"Ll"},{"key":"1D528","mappings":{"default":{"default":"k en gothique"}},"category":"Ll"},{"key":"1D529","mappings":{"default":{"default":"l en gothique"}},"category":"Ll"},{"key":"1D52A","mappings":{"default":{"default":"m en gothique"}},"category":"Ll"},{"key":"1D52B","mappings":{"default":{"default":"n en gothique"}},"category":"Ll"},{"key":"1D52C","mappings":{"default":{"default":"o en gothique"}},"category":"Ll"},{"key":"1D52D","mappings":{"default":{"default":"p en gothique"}},"category":"Ll"},{"key":"1D52E","mappings":{"default":{"default":"q en gothique"}},"category":"Ll"},{"key":"1D52F","mappings":{"default":{"default":"r en gothique"}},"category":"Ll"},{"key":"1D530","mappings":{"default":{"default":"s en gothique"}},"category":"Ll"},{"key":"1D531","mappings":{"default":{"default":"t en gothique"}},"category":"Ll"},{"key":"1D532","mappings":{"default":{"default":"u en gothique"}},"category":"Ll"},{"key":"1D533","mappings":{"default":{"default":"v en gothique"}},"category":"Ll"},{"key":"1D534","mappings":{"default":{"default":"w en gothique"}},"category":"Ll"},{"key":"1D535","mappings":{"default":{"default":"x en gothique"}},"category":"Ll"},{"key":"1D536","mappings":{"default":{"default":"y en gothique"}},"category":"Ll"},{"key":"1D537","mappings":{"default":{"default":"z en gothique"}},"category":"Ll"}]
