[{"locale":"fr"},{"key":"1D434","mappings":{"default":{"default":"A majuscule en italique"}},"category":"Lu"},{"key":"1D435","mappings":{"default":{"default":"B majuscule en italique"}},"category":"Lu"},{"key":"1D436","mappings":{"default":{"default":"C majuscule en italique"}},"category":"Lu"},{"key":"1D437","mappings":{"default":{"default":"D majuscule en italique"}},"category":"Lu"},{"key":"1D438","mappings":{"default":{"default":"E majuscule en italique"}},"category":"Lu"},{"key":"1D439","mappings":{"default":{"default":"F majuscule en italique"}},"category":"Lu"},{"key":"1D43A","mappings":{"default":{"default":"G majuscule en italique"}},"category":"Lu"},{"key":"1D43B","mappings":{"default":{"default":"H majuscule en italique"}},"category":"Lu"},{"key":"1D43C","mappings":{"default":{"default":"I majuscule en italique"}},"category":"Lu"},{"key":"1D43D","mappings":{"default":{"default":"J majuscule en italique"}},"category":"Lu"},{"key":"1D43E","mappings":{"default":{"default":"K majuscule en italique"}},"category":"Lu"},{"key":"1D43F","mappings":{"default":{"default":"L majuscule en italique"}},"category":"Lu"},{"key":"1D440","mappings":{"default":{"default":"M majuscule en italique"}},"category":"Lu"},{"key":"1D441","mappings":{"default":{"default":"N majuscule en italique"}},"category":"Lu"},{"key":"1D442","mappings":{"default":{"default":"O majuscule en italique"}},"category":"Lu"},{"key":"1D443","mappings":{"default":{"default":"P majuscule en italique"}},"category":"Lu"},{"key":"1D444","mappings":{"default":{"default":"Q majuscule en italique"}},"category":"Lu"},{"key":"1D445","mappings":{"default":{"default":"R majuscule en italique"}},"category":"Lu"},{"key":"1D446","mappings":{"default":{"default":"S majuscule en italique"}},"category":"Lu"},{"key":"1D447","mappings":{"default":{"default":"T majuscule en italique"}},"category":"Lu"},{"key":"1D448","mappings":{"default":{"default":"U majuscule en italique"}},"category":"Lu"},{"key":"1D449","mappings":{"default":{"default":"V majuscule en italique"}},"category":"Lu"},{"key":"1D44A","mappings":{"default":{"default":"W majuscule en italique"}},"category":"Lu"},{"key":"1D44B","mappings":{"default":{"default":"X majuscule en italique"}},"category":"Lu"},{"key":"1D44C","mappings":{"default":{"default":"Y majuscule en italique"}},"category":"Lu"},{"key":"1D44D","mappings":{"default":{"default":"Z majuscule en italique"}},"category":"Lu"},{"key":"1D44E","mappings":{"default":{"default":"a en italique"}},"category":"Ll"},{"key":"1D44F","mappings":{"default":{"default":"b en italique"}},"category":"Ll"},{"key":"1D450","mappings":{"default":{"default":"c en italique"}},"category":"Ll"},{"key":"1D451","mappings":{"default":{"default":"d en italique"}},"category":"Ll"},{"key":"1D452","mappings":{"default":{"default":"e en italique"}},"category":"Ll"},{"key":"1D453","mappings":{"default":{"default":"f en italique"}},"category":"Ll"},{"key":"1D454","mappings":{"default":{"default":"g en italique"}},"category":"Ll"},{"key":"210E","mappings":{"default":{"default":"constante de planck"}},"category":"Ll"},{"key":"1D456","mappings":{"default":{"default":"i en italique"}},"category":"Ll"},{"key":"1D457","mappings":{"default":{"default":"j en italique"}},"category":"Ll"},{"key":"1D458","mappings":{"default":{"default":"k en italique"}},"category":"Ll"},{"key":"1D459","mappings":{"default":{"default":"l en italique"}},"category":"Ll"},{"key":"1D45A","mappings":{"default":{"default":"m en italique"}},"category":"Ll"},{"key":"1D45B","mappings":{"default":{"default":"n en italique"}},"category":"Ll"},{"key":"1D45C","mappings":{"default":{"default":"o en italique"}},"category":"Ll"},{"key":"1D45D","mappings":{"default":{"default":"p en italique"}},"category":"Ll"},{"key":"1D45E","mappings":{"default":{"default":"q en italique"}},"category":"Ll"},{"key":"1D45F","mappings":{"default":{"default":"r en italique"}},"category":"Ll"},{"key":"1D460","mappings":{"default":{"default":"s en italique"}},"category":"Ll"},{"key":"1D461","mappings":{"default":{"default":"t en italique"}},"category":"Ll"},{"key":"1D462","mappings":{"default":{"default":"u en italique"}},"category":"Ll"},{"key":"1D463","mappings":{"default":{"default":"v en italique"}},"category":"Ll"},{"key":"1D464","mappings":{"default":{"default":"w en italique"}},"category":"Ll"},{"key":"1D465","mappings":{"default":{"default":"x en italique"}},"category":"Ll"},{"key":"1D466","mappings":{"default":{"default":"y en italique"}},"category":"Ll"},{"key":"1D467","mappings":{"default":{"default":"z en italique"}},"category":"Ll"}]
