[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠠⠁"}},"key":"1D670"},{"category":"Lu","mappings":{"default":{"default":"⠠⠃"}},"key":"1D671"},{"category":"Lu","mappings":{"default":{"default":"⠠⠉"}},"key":"1D672"},{"category":"Lu","mappings":{"default":{"default":"⠠⠙"}},"key":"1D673"},{"category":"Lu","mappings":{"default":{"default":"⠠⠑"}},"key":"1D674"},{"category":"Lu","mappings":{"default":{"default":"⠠⠋"}},"key":"1D675"},{"category":"Lu","mappings":{"default":{"default":"⠠⠛"}},"key":"1D676"},{"category":"Lu","mappings":{"default":{"default":"⠠⠓"}},"key":"1D677"},{"category":"Lu","mappings":{"default":{"default":"⠠⠊"}},"key":"1D678"},{"category":"Lu","mappings":{"default":{"default":"⠠⠚"}},"key":"1D679"},{"category":"Lu","mappings":{"default":{"default":"⠠⠅"}},"key":"1D67A"},{"category":"Lu","mappings":{"default":{"default":"⠠⠇"}},"key":"1D67B"},{"category":"Lu","mappings":{"default":{"default":"⠠⠍"}},"key":"1D67C"},{"category":"Lu","mappings":{"default":{"default":"⠠⠝"}},"key":"1D67D"},{"category":"Lu","mappings":{"default":{"default":"⠠⠕"}},"key":"1D67E"},{"category":"Lu","mappings":{"default":{"default":"⠠⠏"}},"key":"1D67F"},{"category":"Lu","mappings":{"default":{"default":"⠠⠟"}},"key":"1D680"},{"category":"Lu","mappings":{"default":{"default":"⠠⠗"}},"key":"1D681"},{"category":"Lu","mappings":{"default":{"default":"⠠⠎"}},"key":"1D682"},{"category":"Lu","mappings":{"default":{"default":"⠠⠞"}},"key":"1D683"},{"category":"Lu","mappings":{"default":{"default":"⠠⠥"}},"key":"1D684"},{"category":"Lu","mappings":{"default":{"default":"⠠⠧"}},"key":"1D685"},{"category":"Lu","mappings":{"default":{"default":"⠠⠺"}},"key":"1D686"},{"category":"Lu","mappings":{"default":{"default":"⠠⠭"}},"key":"1D687"},{"category":"Lu","mappings":{"default":{"default":"⠠⠽"}},"key":"1D688"},{"category":"Lu","mappings":{"default":{"default":"⠠⠵"}},"key":"1D689"},{"category":"Ll","mappings":{"default":{"default":"⠁"}},"key":"1D68A"},{"category":"Ll","mappings":{"default":{"default":"⠃"}},"key":"1D68B"},{"category":"Ll","mappings":{"default":{"default":"⠉"}},"key":"1D68C"},{"category":"Ll","mappings":{"default":{"default":"⠙"}},"key":"1D68D"},{"category":"Ll","mappings":{"default":{"default":"⠑"}},"key":"1D68E"},{"category":"Ll","mappings":{"default":{"default":"⠋"}},"key":"1D68F"},{"category":"Ll","mappings":{"default":{"default":"⠛"}},"key":"1D690"},{"category":"Ll","mappings":{"default":{"default":"⠓"}},"key":"1D691"},{"category":"Ll","mappings":{"default":{"default":"⠊"}},"key":"1D692"},{"category":"Ll","mappings":{"default":{"default":"⠚"}},"key":"1D693"},{"category":"Ll","mappings":{"default":{"default":"⠅"}},"key":"1D694"},{"category":"Ll","mappings":{"default":{"default":"⠇"}},"key":"1D695"},{"category":"Ll","mappings":{"default":{"default":"⠍"}},"key":"1D696"},{"category":"Ll","mappings":{"default":{"default":"⠝"}},"key":"1D697"},{"category":"Ll","mappings":{"default":{"default":"⠕"}},"key":"1D698"},{"category":"Ll","mappings":{"default":{"default":"⠏"}},"key":"1D699"},{"category":"Ll","mappings":{"default":{"default":"⠟"}},"key":"1D69A"},{"category":"Ll","mappings":{"default":{"default":"⠗"}},"key":"1D69B"},{"category":"Ll","mappings":{"default":{"default":"⠎"}},"key":"1D69C"},{"category":"Ll","mappings":{"default":{"default":"⠞"}},"key":"1D69D"},{"category":"Ll","mappings":{"default":{"default":"⠥"}},"key":"1D69E"},{"category":"Ll","mappings":{"default":{"default":"⠧"}},"key":"1D69F"},{"category":"Ll","mappings":{"default":{"default":"⠺"}},"key":"1D6A0"},{"category":"Ll","mappings":{"default":{"default":"⠭"}},"key":"1D6A1"},{"category":"Ll","mappings":{"default":{"default":"⠽"}},"key":"1D6A2"},{"category":"Ll","mappings":{"default":{"default":"⠵"}},"key":"1D6A3"}]
