[{"locale":"en"},{"category":"volume","mappings":{"default":{"default":"barrel"}},"key":"bbl","names":["bbl.","bbl"]},{"category":"volume","mappings":{"default":{"default":"cubic"}},"key":"cu","names":["cu","cu."]},{"category":"volume","mappings":{"default":{"default":"fluid ounce"}},"key":"fl. oz.","names":["fl. oz."]},{"category":"volume","mappings":{"default":{"default":"gallon"}},"key":"gal","names":["gal","gal."]},{"category":"volume","mappings":{"default":{"default":"pint"}},"key":"pt","names":["pt","pt."]},{"category":"volume","mappings":{"default":{"default":"quart"}},"key":"qt","names":["qt","qt."]},{"category":"volume","mappings":{"default":{"default":"tablespoon"}},"key":"tbsp","names":["tbsp","tbsp."]},{"category":"volume","mappings":{"default":{"default":"teaspoon"}},"key":"tsp","names":["tsp","tsp."]},{"category":"volume","mappings":{"default":{"default":"cubic centimeter"}},"key":"cc","names":["cc"]},{"category":"volume","mappings":{"default":{"default":"kiloliter"}},"key":"kl","names":["kl"]},{"category":"volume","mappings":{"default":{"default":"liter"}},"key":"l","names":["l"]},{"category":"volume","mappings":{"default":{"default":"milliliter"}},"key":"ml","names":["ml"]}]
