[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠁"}},"key":"1D6A8"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠃"}},"key":"1D6A9"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠛"}},"key":"1D6AA"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠙"}},"key":"1D6AB"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠑"}},"key":"1D6AC"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠱"}},"key":"1D6AD"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠣"}},"key":"1D6AE"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠹"}},"key":"1D6AF"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠊"}},"key":"1D6B0"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠅"}},"key":"1D6B1"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠇"}},"key":"1D6B2"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠍"}},"key":"1D6B3"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠝"}},"key":"1D6B4"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠭"}},"key":"1D6B5"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠕"}},"key":"1D6B6"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠏"}},"key":"1D6B7"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠗"}},"key":"1D6B8"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠎"}},"key":"1D6BA"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠥"}},"key":"1D6BB"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠥"}},"key":"1D6BC"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠋"}},"key":"1D6BD"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠯"}},"key":"1D6BE"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠫"}},"key":"1D6BF"},{"category":"Lu","mappings":{"default":{"default":"⠸⠨⠠⠺"}},"key":"1D6C0"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠁"}},"key":"1D6C2"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠃"}},"key":"1D6C3"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠛"}},"key":"1D6C4"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠙"}},"key":"1D6C5"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠑"}},"key":"1D6C6"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠱"}},"key":"1D6C7"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠦"}},"key":"1D6C8"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠹"}},"key":"1D6C9"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠊"}},"key":"1D6CA"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠅"}},"key":"1D6CB"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠇"}},"key":"1D6CC"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠍"}},"key":"1D6CD"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠝"}},"key":"1D6CE"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠭"}},"key":"1D6CF"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠕"}},"key":"1D6D0"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠏"}},"key":"1D6D1"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠗"}},"key":"1D6D2"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠒"}},"key":"1D6D3"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠎"}},"key":"1D6D4"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠞"}},"key":"1D6D5"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠥"}},"key":"1D6D6"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠋"}},"key":"1D6D7"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠯"}},"key":"1D6D8"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠓"}},"key":"1D6D9"},{"category":"Ll","mappings":{"default":{"default":"⠸⠨⠕"}},"key":"1D6DA"}]
