[{"locale":"fr"},{"key":"00F8","mappings":{"default":{"default":"o barré"}},"category":"Ll"},{"key":"0111","mappings":{"default":{"default":"d barré"}},"category":"Ll"},{"key":"0127","mappings":{"default":{"default":"h barré"}},"category":"Ll"},{"key":"0142","mappings":{"default":{"default":"l barré"}},"category":"Ll"},{"key":"0167","mappings":{"default":{"default":"t barré"}},"category":"Ll"},{"key":"019B","mappings":{"default":{"default":"lambda barré"}},"category":"Ll"},{"key":"1E9B","mappings":{"default":{"default":"s long point en chef"}},"category":"Ll"},{"key":"0138","mappings":{"default":{"default":"kra"}},"category":"Ll"},{"key":"0192","mappings":{"default":{"default":"f cursif"}},"category":"Ll"},{"key":"019A","mappings":{"default":{"default":"l rayé"}},"category":"Ll"},{"key":"025B","mappings":{"default":{"default":"e ouvert"}},"category":"Ll"},{"key":"0149","mappings":{"default":{"default":"n précédée d'une apostrophe"}},"category":"Ll"},{"key":"014B","mappings":{"default":{"default":"eng"}},"category":"Ll"}]
