[{"locale":"fr"},{"key":"22BE","mappings":{"default":{"default":"angle droit avec arc"}},"category":"Sm"},{"key":"237C","mappings":{"default":{"default":"angle droit avec flèche en zigzag vers le bas"}},"category":"Sm"},{"key":"27C0","mappings":{"default":{"default":"angle tridimensionnel"}},"category":"Sm"},{"key":"299D","mappings":{"default":{"default":"angle droit mesuré pointé"}},"category":"Sm"},{"key":"29A4","mappings":{"default":{"default":"angle à barre souscrite"}},"category":"Sm"},{"key":"29A5","mappings":{"default":{"default":"angle à barre souscrite réfléchie"}},"category":"Sm"},{"key":"29A6","mappings":{"default":{"default":"angle oblique s'ouvrant vers le haut"}},"category":"Sm"},{"key":"29A7","mappings":{"default":{"default":"angle oblique s'ouvrant vers le bas"}},"category":"Sm"},{"key":"29A8","mappings":{"default":{"default":"angle calculé à bras vers l'est et bras fléché vers le nord-est"}},"category":"Sm"},{"key":"29A9","mappings":{"default":{"default":"angle calculé à bras vers l'ouest et bras fléché vers le nord-ouest"}},"category":"Sm"},{"key":"29AA","mappings":{"default":{"default":"angle calculé à bras vers l'est et bras fléché vers le sud-est"}},"category":"Sm"},{"key":"29AB","mappings":{"default":{"default":"angle calculé à bras vers l'ouest et bras fléché vers le sud-ouest"}},"category":"Sm"},{"key":"29AC","mappings":{"default":{"default":"angle calculé à bras vers le nord et bras fléché vers le nord-est"}},"category":"Sm"},{"key":"29AD","mappings":{"default":{"default":"angle calculé à bras vers le nord et bras fléché vers le nord-ouest"}},"category":"Sm"},{"key":"29AE","mappings":{"default":{"default":"angle calculé à bras vers le sud et bras fléché vers le sud-est"}},"category":"Sm"},{"key":"29AF","mappings":{"default":{"default":"angle calculé à bras vers le sud et bras fléché vers le sud-ouest"}},"category":"Sm"}]
