[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠁"}},"key":"1D4D0"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠃"}},"key":"1D4D1"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠉"}},"key":"1D4D2"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠙"}},"key":"1D4D3"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠑"}},"key":"1D4D4"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠋"}},"key":"1D4D5"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠛"}},"key":"1D4D6"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠓"}},"key":"1D4D7"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠊"}},"key":"1D4D8"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠚"}},"key":"1D4D9"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠅"}},"key":"1D4DA"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠇"}},"key":"1D4DB"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠍"}},"key":"1D4DC"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠝"}},"key":"1D4DD"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠕"}},"key":"1D4DE"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠏"}},"key":"1D4DF"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠟"}},"key":"1D4E0"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠗"}},"key":"1D4E1"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠎"}},"key":"1D4E2"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠞"}},"key":"1D4E3"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠥"}},"key":"1D4E4"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠧"}},"key":"1D4E5"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠺"}},"key":"1D4E6"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠭"}},"key":"1D4E7"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠽"}},"key":"1D4E8"},{"category":"Lu","mappings":{"default":{"default":"⠸⠈⠠⠵"}},"key":"1D4E9"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠁"}},"key":"1D4EA"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠃"}},"key":"1D4EB"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠉"}},"key":"1D4EC"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠙"}},"key":"1D4ED"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠑"}},"key":"1D4EE"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠋"}},"key":"1D4EF"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠛"}},"key":"1D4F0"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠓"}},"key":"1D4F1"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠊"}},"key":"1D4F2"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠚"}},"key":"1D4F3"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠅"}},"key":"1D4F4"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠇"}},"key":"1D4F5"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠍"}},"key":"1D4F6"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠝"}},"key":"1D4F7"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠕"}},"key":"1D4F8"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠏"}},"key":"1D4F9"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠟"}},"key":"1D4FA"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠗"}},"key":"1D4FB"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠎"}},"key":"1D4FC"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠞"}},"key":"1D4FD"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠥"}},"key":"1D4FE"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠧"}},"key":"1D4FF"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠺"}},"key":"1D500"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠭"}},"key":"1D501"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠽"}},"key":"1D502"},{"category":"Ll","mappings":{"default":{"default":"⠸⠈⠵"}},"key":"1D503"}]
