[{"locale":"fr"},{"key":"1D49C","mappings":{"default":{"default":"A majuscule en script"}},"category":"Lu"},{"key":"212C","mappings":{"default":{"default":"B ronde majuscule"}},"category":"Lu"},{"key":"1D49E","mappings":{"default":{"default":"C majuscule en script"}},"category":"Lu"},{"key":"1D49F","mappings":{"default":{"default":"D majuscule en script"}},"category":"Lu"},{"key":"2130","mappings":{"default":{"default":"E ronde majuscule"}},"category":"Lu"},{"key":"2131","mappings":{"default":{"default":"F ronde majuscule"}},"category":"Lu"},{"key":"1D4A2","mappings":{"default":{"default":"G majuscule en script"}},"category":"Lu"},{"key":"210B","mappings":{"default":{"default":"H ronde majuscule"}},"category":"Lu"},{"key":"2110","mappings":{"default":{"default":"I ronde majuscule"}},"category":"Lu"},{"key":"1D4A5","mappings":{"default":{"default":"J majuscule en script"}},"category":"Lu"},{"key":"1D4A6","mappings":{"default":{"default":"K majuscule en script"}},"category":"Lu"},{"key":"2112","mappings":{"default":{"default":"L ronde majuscule"}},"category":"Lu"},{"key":"2133","mappings":{"default":{"default":"M ronde majuscule"}},"category":"Lu"},{"key":"1D4A9","mappings":{"default":{"default":"N majuscule en script"}},"category":"Lu"},{"key":"1D4AA","mappings":{"default":{"default":"O majuscule en script"}},"category":"Lu"},{"key":"1D4AB","mappings":{"default":{"default":"P majuscule en script"}},"category":"Lu"},{"key":"1D4AC","mappings":{"default":{"default":"Q majuscule en script"}},"category":"Lu"},{"key":"211B","mappings":{"default":{"default":"R ronde majuscule"}},"category":"Lu"},{"key":"1D4AE","mappings":{"default":{"default":"S majuscule en script"}},"category":"Lu"},{"key":"1D4AF","mappings":{"default":{"default":"T majuscule en script"}},"category":"Lu"},{"key":"1D4B0","mappings":{"default":{"default":"U majuscule en script"}},"category":"Lu"},{"key":"1D4B1","mappings":{"default":{"default":"V majuscule en script"}},"category":"Lu"},{"key":"1D4B2","mappings":{"default":{"default":"W majuscule en script"}},"category":"Lu"},{"key":"1D4B3","mappings":{"default":{"default":"X majuscule en script"}},"category":"Lu"},{"key":"1D4B4","mappings":{"default":{"default":"Y majuscule en script"}},"category":"Lu"},{"key":"1D4B5","mappings":{"default":{"default":"Z majuscule en script"}},"category":"Lu"},{"key":"1D4B6","mappings":{"default":{"default":"a en script"}},"category":"Ll"},{"key":"1D4B7","mappings":{"default":{"default":"b en script"}},"category":"Ll"},{"key":"1D4B8","mappings":{"default":{"default":"c en script"}},"category":"Ll"},{"key":"1D4B9","mappings":{"default":{"default":"d en script"}},"category":"Ll"},{"key":"212F","mappings":{"default":{"default":"e ronde minuscule"}},"category":"Ll"},{"key":"1D4BB","mappings":{"default":{"default":"f en script"}},"category":"Ll"},{"key":"210A","mappings":{"default":{"default":"g ronde minuscule"}},"category":"Ll"},{"key":"1D4BD","mappings":{"default":{"default":"h en script"}},"category":"Ll"},{"key":"1D4BE","mappings":{"default":{"default":"i en script"}},"category":"Ll"},{"key":"1D4BF","mappings":{"default":{"default":"j en script"}},"category":"Ll"},{"key":"1D4C0","mappings":{"default":{"default":"k en script"}},"category":"Ll"},{"key":"1D4C2","mappings":{"default":{"default":"m en script"}},"category":"Ll"},{"key":"1D4C3","mappings":{"default":{"default":"n en script"}},"category":"Ll"},{"key":"2134","mappings":{"default":{"default":"o ronde minuscule"}},"category":"Ll"},{"key":"1D4C5","mappings":{"default":{"default":"p en script"}},"category":"Ll"},{"key":"1D4C6","mappings":{"default":{"default":"q en script"}},"category":"Ll"},{"key":"1D4C7","mappings":{"default":{"default":"r en script"}},"category":"Ll"},{"key":"1D4C8","mappings":{"default":{"default":"s en script"}},"category":"Ll"},{"key":"1D4C9","mappings":{"default":{"default":"t en script"}},"category":"Ll"},{"key":"1D4CA","mappings":{"default":{"default":"u en script"}},"category":"Ll"},{"key":"1D4CB","mappings":{"default":{"default":"v en script"}},"category":"Ll"},{"key":"1D4CC","mappings":{"default":{"default":"w en script"}},"category":"Ll"},{"key":"1D4CD","mappings":{"default":{"default":"x en script"}},"category":"Ll"},{"key":"1D4CE","mappings":{"default":{"default":"y en script"}},"category":"Ll"},{"key":"1D4CF","mappings":{"default":{"default":"z en script"}},"category":"Ll"}]
