[{"locale":"fr"},{"key":"2113","mappings":{"default":{"default":"l minuscule en script"}},"category":"Ll"},{"key":"2118","mappings":{"default":{"default":"fonction elliptique de weierstrass"}},"category":"Sm"},{"key":"2145","mappings":{"default":{"default":"D majuscule"}},"category":"Lu"},{"key":"2146","mappings":{"default":{"default":"d minuscule ajouré en italique"}},"category":"Ll"},{"key":"2147","mappings":{"default":{"default":"e minuscule ajouré en italique"}},"category":"Ll"},{"key":"2148","mappings":{"default":{"default":"i minuscule ajouré en italique"}},"category":"Ll"},{"key":"1D6A4","mappings":{"default":{"default":"dotless i"}},"category":"Ll"},{"key":"1D6A5","mappings":{"default":{"default":"dotless j"}},"category":"Ll"}]
