[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠁"}},"key":"1D400"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠃"}},"key":"1D401"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠉"}},"key":"1D402"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠙"}},"key":"1D403"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠑"}},"key":"1D404"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠋"}},"key":"1D405"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠛"}},"key":"1D406"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠓"}},"key":"1D407"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠊"}},"key":"1D408"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠚"}},"key":"1D409"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠅"}},"key":"1D40A"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠇"}},"key":"1D40B"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠍"}},"key":"1D40C"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠝"}},"key":"1D40D"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠕"}},"key":"1D40E"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠏"}},"key":"1D40F"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠟"}},"key":"1D410"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠗"}},"key":"1D411"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠎"}},"key":"1D412"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠞"}},"key":"1D413"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠥"}},"key":"1D414"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠧"}},"key":"1D415"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠺"}},"key":"1D416"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠭"}},"key":"1D417"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠽"}},"key":"1D418"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠵"}},"key":"1D419"},{"category":"Ll","mappings":{"default":{"default":"⠸⠁"}},"key":"1D41A"},{"category":"Ll","mappings":{"default":{"default":"⠸⠃"}},"key":"1D41B"},{"category":"Ll","mappings":{"default":{"default":"⠸⠉"}},"key":"1D41C"},{"category":"Ll","mappings":{"default":{"default":"⠸⠙"}},"key":"1D41D"},{"category":"Ll","mappings":{"default":{"default":"⠸⠑"}},"key":"1D41E"},{"category":"Ll","mappings":{"default":{"default":"⠸⠋"}},"key":"1D41F"},{"category":"Ll","mappings":{"default":{"default":"⠸⠛"}},"key":"1D420"},{"category":"Ll","mappings":{"default":{"default":"⠸⠓"}},"key":"1D421"},{"category":"Ll","mappings":{"default":{"default":"⠸⠊"}},"key":"1D422"},{"category":"Ll","mappings":{"default":{"default":"⠸⠚"}},"key":"1D423"},{"category":"Ll","mappings":{"default":{"default":"⠸⠅"}},"key":"1D424"},{"category":"Ll","mappings":{"default":{"default":"⠸⠇"}},"key":"1D425"},{"category":"Ll","mappings":{"default":{"default":"⠸⠍"}},"key":"1D426"},{"category":"Ll","mappings":{"default":{"default":"⠸⠝"}},"key":"1D427"},{"category":"Ll","mappings":{"default":{"default":"⠸⠕"}},"key":"1D428"},{"category":"Ll","mappings":{"default":{"default":"⠸⠏"}},"key":"1D429"},{"category":"Ll","mappings":{"default":{"default":"⠸⠟"}},"key":"1D42A"},{"category":"Ll","mappings":{"default":{"default":"⠸⠗"}},"key":"1D42B"},{"category":"Ll","mappings":{"default":{"default":"⠸⠎"}},"key":"1D42C"},{"category":"Ll","mappings":{"default":{"default":"⠸⠞"}},"key":"1D42D"},{"category":"Ll","mappings":{"default":{"default":"⠸⠥"}},"key":"1D42E"},{"category":"Ll","mappings":{"default":{"default":"⠸⠧"}},"key":"1D42F"},{"category":"Ll","mappings":{"default":{"default":"⠸⠺"}},"key":"1D430"},{"category":"Ll","mappings":{"default":{"default":"⠸⠭"}},"key":"1D431"},{"category":"Ll","mappings":{"default":{"default":"⠸⠽"}},"key":"1D432"},{"category":"Ll","mappings":{"default":{"default":"⠸⠵"}},"key":"1D433"}]
