[{"locale":"fr"},{"key":"0391","mappings":{"default":{"default":"Alpha majuscule"}},"category":"Lu"},{"key":"0392","mappings":{"default":{"default":"Bêta majuscule"}},"category":"Lu"},{"key":"0393","mappings":{"default":{"default":"Gamma majuscule"}},"category":"Lu"},{"key":"0394","mappings":{"default":{"default":"Delta majuscule"}},"category":"Lu"},{"key":"0395","mappings":{"default":{"default":"Epsilon majuscule"}},"category":"Lu"},{"key":"0396","mappings":{"default":{"default":"Zêta majuscule"}},"category":"Lu"},{"key":"0397","mappings":{"default":{"default":"Êta majuscule"}},"category":"Lu"},{"key":"0398","mappings":{"default":{"default":"Thêta majuscule"}},"category":"Lu"},{"key":"0399","mappings":{"default":{"default":"Iota majuscule"}},"category":"Lu"},{"key":"039A","mappings":{"default":{"default":"Kappa majuscule"}},"category":"Lu"},{"key":"039B","mappings":{"default":{"default":"Lambda majuscule"}},"category":"Lu"},{"key":"039C","mappings":{"default":{"default":"Mû majuscule"}},"category":"Lu"},{"key":"039D","mappings":{"default":{"default":"Nû majuscule"}},"category":"Lu"},{"key":"039E","mappings":{"default":{"default":"Xi majuscule"}},"category":"Lu"},{"key":"039F","mappings":{"default":{"default":"Omicron majuscule"}},"category":"Lu"},{"key":"03A0","mappings":{"default":{"default":"Pi majuscule"}},"category":"Lu"},{"key":"03A1","mappings":{"default":{"default":"Rho majuscule"}},"category":"Lu"},{"key":"03A3","mappings":{"default":{"default":"Sigma majuscule"}},"category":"Lu"},{"key":"03A4","mappings":{"default":{"default":"Tau majuscule"}},"category":"Lu"},{"key":"03A5","mappings":{"default":{"default":"Upsilon majuscule"}},"category":"Lu"},{"key":"03A6","mappings":{"default":{"default":"Phi majuscule"}},"category":"Lu"},{"key":"03A7","mappings":{"default":{"default":"Chi majuscule"}},"category":"Lu"},{"key":"03A8","mappings":{"default":{"default":"Psi majuscule"}},"category":"Lu"},{"key":"03A9","mappings":{"default":{"default":"Oméga majuscule"}},"category":"Lu"}]
