[{"locale":"nemeth"},{"category":"Lu","key":"0041","mappings":{"default":{"default":"⠠⠁"}}},{"category":"Lu","key":"0042","mappings":{"default":{"default":"⠠⠃"}}},{"category":"Lu","key":"0043","mappings":{"default":{"default":"⠠⠉"}}},{"category":"Lu","key":"0044","mappings":{"default":{"default":"⠠⠙"}}},{"category":"Lu","key":"0045","mappings":{"default":{"default":"⠠⠑"}}},{"category":"Lu","key":"0046","mappings":{"default":{"default":"⠠⠋"}}},{"category":"Lu","key":"0047","mappings":{"default":{"default":"⠠⠛"}}},{"category":"Lu","key":"0048","mappings":{"default":{"default":"⠠⠓"}}},{"category":"Lu","key":"0049","mappings":{"default":{"default":"⠠⠊"}}},{"category":"Lu","key":"004A","mappings":{"default":{"default":"⠠⠚"}}},{"category":"Lu","key":"004B","mappings":{"default":{"default":"⠠⠅"}}},{"category":"Lu","key":"004C","mappings":{"default":{"default":"⠠⠇"}}},{"category":"Lu","key":"004D","mappings":{"default":{"default":"⠠⠍"}}},{"category":"Lu","key":"004E","mappings":{"default":{"default":"⠠⠝"}}},{"category":"Lu","key":"004F","mappings":{"default":{"default":"⠠⠕"}}},{"category":"Lu","key":"0050","mappings":{"default":{"default":"⠠⠏"}}},{"category":"Lu","key":"0051","mappings":{"default":{"default":"⠠⠟"}}},{"category":"Lu","key":"0052","mappings":{"default":{"default":"⠠⠗"}}},{"category":"Lu","key":"0053","mappings":{"default":{"default":"⠠⠎"}}},{"category":"Lu","key":"0054","mappings":{"default":{"default":"⠠⠞"}}},{"category":"Lu","key":"0055","mappings":{"default":{"default":"⠠⠥"}}},{"category":"Lu","key":"0056","mappings":{"default":{"default":"⠠⠧"}}},{"category":"Lu","key":"0057","mappings":{"default":{"default":"⠠⠺"}}},{"category":"Lu","key":"0058","mappings":{"default":{"default":"⠠⠭"}}},{"category":"Lu","key":"0059","mappings":{"default":{"default":"⠠⠽"}}},{"category":"Lu","key":"005A","mappings":{"default":{"default":"⠠⠵"}}},{"category":"Lu","key":"FF21","mappings":{"default":{"default":"⠠⠁"}}},{"category":"Lu","key":"FF22","mappings":{"default":{"default":"⠠⠃"}}},{"category":"Lu","key":"FF23","mappings":{"default":{"default":"⠠⠉"}}},{"category":"Lu","key":"FF24","mappings":{"default":{"default":"⠠⠙"}}},{"category":"Lu","key":"FF25","mappings":{"default":{"default":"⠠⠑"}}},{"category":"Lu","key":"FF26","mappings":{"default":{"default":"⠠⠋"}}},{"category":"Lu","key":"FF27","mappings":{"default":{"default":"⠠⠛"}}},{"category":"Lu","key":"FF28","mappings":{"default":{"default":"⠠⠓"}}},{"category":"Lu","key":"FF29","mappings":{"default":{"default":"⠠⠊"}}},{"category":"Lu","key":"FF2A","mappings":{"default":{"default":"⠠⠚"}}},{"category":"Lu","key":"FF2B","mappings":{"default":{"default":"⠠⠅"}}},{"category":"Lu","key":"FF2C","mappings":{"default":{"default":"⠠⠇"}}},{"category":"Lu","key":"FF2D","mappings":{"default":{"default":"⠠⠍"}}},{"category":"Lu","key":"FF2E","mappings":{"default":{"default":"⠠⠝"}}},{"category":"Lu","key":"FF2F","mappings":{"default":{"default":"⠠⠕"}}},{"category":"Lu","key":"FF30","mappings":{"default":{"default":"⠠⠏"}}},{"category":"Lu","key":"FF31","mappings":{"default":{"default":"⠠⠟"}}},{"category":"Lu","key":"FF32","mappings":{"default":{"default":"⠠⠗"}}},{"category":"Lu","key":"FF33","mappings":{"default":{"default":"⠠⠎"}}},{"category":"Lu","key":"FF34","mappings":{"default":{"default":"⠠⠞"}}},{"category":"Lu","key":"FF35","mappings":{"default":{"default":"⠠⠥"}}},{"category":"Lu","key":"FF36","mappings":{"default":{"default":"⠠⠧"}}},{"category":"Lu","key":"FF37","mappings":{"default":{"default":"⠠⠺"}}},{"category":"Lu","key":"FF38","mappings":{"default":{"default":"⠠⠭"}}},{"category":"Lu","key":"FF39","mappings":{"default":{"default":"⠠⠽"}}},{"category":"Lu","key":"FF3A","mappings":{"default":{"default":"⠠⠵"}}}]
