[{"locale":"fr"},{"key":"2605","mappings":{"default":{"default":"étoile noire"}},"category":"So"},{"key":"2606","mappings":{"default":{"default":"étoile blanche"}},"category":"So"},{"key":"2713","mappings":{"default":{"default":"signe de vérification"}},"category":"So"},{"key":"2717","mappings":{"default":{"default":"x de bulletin de vote"}},"category":"So"},{"key":"2720","mappings":{"default":{"default":"croix de malte"}},"category":"So"},{"key":"2736","mappings":{"default":{"default":"étoile noire à six branches"}},"category":"So"},{"key":"273D","mappings":{"default":{"default":"gros astérisque larmé"}},"category":"So"}]
