[{"locale":"en"},{"category":"time","mappings":{"default":{"default":"nanosecond"}},"key":"ns","names":["ns"]},{"category":"time","mappings":{"default":{"default":"microsecond"}},"key":"µs","names":["µs"]},{"category":"time","mappings":{"default":{"default":"millisecond"}},"key":"ms","names":["ms"]},{"category":"time","mappings":{"default":{"default":"second"}},"key":"s","names":["s"]},{"category":"time","mappings":{"default":{"default":"minute"}},"key":"min","names":["min"]},{"category":"time","mappings":{"default":{"default":"hour"}},"key":"h","names":["h","hr"]}]
