[{"locale":"nemeth"},{"category":"","mappings":{"default":{"default":"⠙⠕⠵"}},"key":"doz","names":["doz","doz.","dz","dz."]},{"category":"","mappings":{"default":{"default":"⠎⠟"}},"key":"sq","names":["sq","sq."]},{"category":"","mappings":{"default":{"default":"⠓⠁"}},"key":"ha","names":["ha"]}]
