[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠁"}},"key":"1D5A0"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠃"}},"key":"1D5A1"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠉"}},"key":"1D5A2"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠙"}},"key":"1D5A3"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠑"}},"key":"1D5A4"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠋"}},"key":"1D5A5"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠛"}},"key":"1D5A6"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠓"}},"key":"1D5A7"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠊"}},"key":"1D5A8"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠚"}},"key":"1D5A9"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠅"}},"key":"1D5AA"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠇"}},"key":"1D5AB"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠍"}},"key":"1D5AC"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠝"}},"key":"1D5AD"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠕"}},"key":"1D5AE"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠏"}},"key":"1D5AF"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠟"}},"key":"1D5B0"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠗"}},"key":"1D5B1"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠎"}},"key":"1D5B2"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠞"}},"key":"1D5B3"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠥"}},"key":"1D5B4"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠧"}},"key":"1D5B5"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠺"}},"key":"1D5B6"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠭"}},"key":"1D5B7"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠽"}},"key":"1D5B8"},{"category":"Lu","mappings":{"default":{"default":"⠠⠨⠠⠵"}},"key":"1D5B9"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠁"}},"key":"1D5BA"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠃"}},"key":"1D5BB"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠉"}},"key":"1D5BC"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠙"}},"key":"1D5BD"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠑"}},"key":"1D5BE"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠋"}},"key":"1D5BF"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠛"}},"key":"1D5C0"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠓"}},"key":"1D5C1"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠊"}},"key":"1D5C2"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠚"}},"key":"1D5C3"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠅"}},"key":"1D5C4"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠇"}},"key":"1D5C5"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠍"}},"key":"1D5C6"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠝"}},"key":"1D5C7"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠕"}},"key":"1D5C8"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠏"}},"key":"1D5C9"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠟"}},"key":"1D5CA"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠗"}},"key":"1D5CB"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠎"}},"key":"1D5CC"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠞"}},"key":"1D5CD"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠥"}},"key":"1D5CE"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠧"}},"key":"1D5CF"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠺"}},"key":"1D5D0"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠭"}},"key":"1D5D1"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠽"}},"key":"1D5D2"},{"category":"Ll","mappings":{"default":{"default":"⠠⠨⠵"}},"key":"1D5D3"}]
