[{"locale":"nemeth"},{"category":"volume","mappings":{"default":{"default":"⠃⠃⠇"}},"key":"bbl","names":["bbl.","bbl"]},{"category":"volume","mappings":{"default":{"default":"⠉⠥"}},"key":"cu","names":["cu","cu."]},{"category":"volume","mappings":{"default":{"default":"⠋⠇⠸⠲⠀⠕⠵⠸⠲"}},"key":"fl. oz.","names":["fl. oz."]},{"category":"volume","mappings":{"default":{"default":"⠛⠁⠇"}},"key":"gal","names":["gal","gal."]},{"category":"volume","mappings":{"default":{"default":"⠏⠞"}},"key":"pt","names":["pt","pt."]},{"category":"volume","mappings":{"default":{"default":"⠟⠞"}},"key":"qt","names":["qt","qt."]},{"category":"volume","mappings":{"default":{"default":"⠞⠃⠎⠏"}},"key":"tbsp","names":["tbsp","tbsp."]},{"category":"volume","mappings":{"default":{"default":"⠞⠎⠏"}},"key":"tsp","names":["tsp","tsp."]},{"category":"volume","mappings":{"default":{"default":"⠉⠉"}},"key":"cc","names":["cc"]},{"category":"volume","mappings":{"default":{"default":"⠅⠇"}},"key":"kl","names":["kl"]},{"category":"volume","mappings":{"default":{"default":"⠇"}},"key":"l","names":["l"]},{"category":"volume","mappings":{"default":{"default":"⠍⠇"}},"key":"ml","names":["ml"]}]
