[{"locale":"fr"},{"key":"1D56C","mappings":{"default":{"default":"A majuscule en gothique gras"}},"category":"Lu"},{"key":"1D56D","mappings":{"default":{"default":"B majuscule en gothique gras"}},"category":"Lu"},{"key":"1D56E","mappings":{"default":{"default":"C majuscule en gothique gras"}},"category":"Lu"},{"key":"1D56F","mappings":{"default":{"default":"D majuscule en gothique gras"}},"category":"Lu"},{"key":"1D570","mappings":{"default":{"default":"E majuscule en gothique gras"}},"category":"Lu"},{"key":"1D571","mappings":{"default":{"default":"F majuscule en gothique gras"}},"category":"Lu"},{"key":"1D572","mappings":{"default":{"default":"G majuscule en gothique gras"}},"category":"Lu"},{"key":"1D573","mappings":{"default":{"default":"H majuscule en gothique gras"}},"category":"Lu"},{"key":"1D574","mappings":{"default":{"default":"I majuscule en gothique gras"}},"category":"Lu"},{"key":"1D575","mappings":{"default":{"default":"J majuscule en gothique gras"}},"category":"Lu"},{"key":"1D576","mappings":{"default":{"default":"K majuscule en gothique gras"}},"category":"Lu"},{"key":"1D577","mappings":{"default":{"default":"L majuscule en gothique gras"}},"category":"Lu"},{"key":"1D578","mappings":{"default":{"default":"M majuscule en gothique gras"}},"category":"Lu"},{"key":"1D579","mappings":{"default":{"default":"N majuscule en gothique gras"}},"category":"Lu"},{"key":"1D57A","mappings":{"default":{"default":"O majuscule en gothique gras"}},"category":"Lu"},{"key":"1D57B","mappings":{"default":{"default":"P majuscule en gothique gras"}},"category":"Lu"},{"key":"1D57C","mappings":{"default":{"default":"Q majuscule en gothique gras"}},"category":"Lu"},{"key":"1D57D","mappings":{"default":{"default":"R majuscule en gothique gras"}},"category":"Lu"},{"key":"1D57E","mappings":{"default":{"default":"S majuscule en gothique gras"}},"category":"Lu"},{"key":"1D57F","mappings":{"default":{"default":"T majuscule en gothique gras"}},"category":"Lu"},{"key":"1D580","mappings":{"default":{"default":"U majuscule en gothique gras"}},"category":"Lu"},{"key":"1D581","mappings":{"default":{"default":"V majuscule en gothique gras"}},"category":"Lu"},{"key":"1D582","mappings":{"default":{"default":"W majuscule en gothique gras"}},"category":"Lu"},{"key":"1D583","mappings":{"default":{"default":"X majuscule en gothique gras"}},"category":"Lu"},{"key":"1D584","mappings":{"default":{"default":"Y majuscule en gothique gras"}},"category":"Lu"},{"key":"1D585","mappings":{"default":{"default":"Z majuscule en gothique gras"}},"category":"Lu"},{"key":"1D586","mappings":{"default":{"default":"a en gothique gras"}},"category":"Ll"},{"key":"1D587","mappings":{"default":{"default":"b en gothique gras"}},"category":"Ll"},{"key":"1D588","mappings":{"default":{"default":"c en gothique gras"}},"category":"Ll"},{"key":"1D589","mappings":{"default":{"default":"d en gothique gras"}},"category":"Ll"},{"key":"1D58A","mappings":{"default":{"default":"e en gothique gras"}},"category":"Ll"},{"key":"1D58B","mappings":{"default":{"default":"f en gothique gras"}},"category":"Ll"},{"key":"1D58C","mappings":{"default":{"default":"g en gothique gras"}},"category":"Ll"},{"key":"1D58D","mappings":{"default":{"default":"h en gothique gras"}},"category":"Ll"},{"key":"1D58E","mappings":{"default":{"default":"i en gothique gras"}},"category":"Ll"},{"key":"1D58F","mappings":{"default":{"default":"j en gothique gras"}},"category":"Ll"},{"key":"1D590","mappings":{"default":{"default":"k en gothique gras"}},"category":"Ll"},{"key":"1D591","mappings":{"default":{"default":"l en gothique gras"}},"category":"Ll"},{"key":"1D592","mappings":{"default":{"default":"m en gothique gras"}},"category":"Ll"},{"key":"1D593","mappings":{"default":{"default":"n en gothique gras"}},"category":"Ll"},{"key":"1D594","mappings":{"default":{"default":"o en gothique gras"}},"category":"Ll"},{"key":"1D595","mappings":{"default":{"default":"p en gothique gras"}},"category":"Ll"},{"key":"1D596","mappings":{"default":{"default":"q en gothique gras"}},"category":"Ll"},{"key":"1D597","mappings":{"default":{"default":"r en gothique gras"}},"category":"Ll"},{"key":"1D598","mappings":{"default":{"default":"s en gothique gras"}},"category":"Ll"},{"key":"1D599","mappings":{"default":{"default":"t en gothique gras"}},"category":"Ll"},{"key":"1D59A","mappings":{"default":{"default":"u en gothique gras"}},"category":"Ll"},{"key":"1D59B","mappings":{"default":{"default":"v en gothique gras"}},"category":"Ll"},{"key":"1D59C","mappings":{"default":{"default":"w en gothique gras"}},"category":"Ll"},{"key":"1D59D","mappings":{"default":{"default":"x en gothique gras"}},"category":"Ll"},{"key":"1D59E","mappings":{"default":{"default":"y en gothique gras"}},"category":"Ll"},{"key":"1D59F","mappings":{"default":{"default":"z en gothique gras"}},"category":"Ll"}]
