[{"locale":"fr"},{"key":"F","mappings":{"default":{"default":"farads","singular":"farad","dual":""}},"names":["F","F.","°F"]},{"key":"C","mappings":{"default":{"default":"coulombs","singular":"coulomb","dual":""}},"names":["C","°C"]},{"key":"K","mappings":{"default":{"default":"kelvins","singular":"kelvin","dual":""}},"names":["K","°K"]}]
