[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Alfa"}},"key":"1D71C"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Beta"}},"key":"1D71D"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Gamma"}},"key":"1D71E"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Delta"}},"key":"1D71F"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Épsilon"}},"key":"1D720"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Zeta"}},"key":"1D721"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Eta"}},"key":"1D722"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Theta"}},"key":"1D723"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Iota"}},"key":"1D724"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Kappa"}},"key":"1D725"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Lambda"}},"key":"1D726"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Mi"}},"key":"1D727"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Ni"}},"key":"1D728"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Xi"}},"key":"1D729"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Ómicron"}},"key":"1D72A"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Pi"}},"key":"1D72B"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Rho"}},"key":"1D72C"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Sigma"}},"key":"1D72E"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Tau"}},"key":"1D72F"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Ípsilon"}},"key":"1D730"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Phi"}},"key":"1D731"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Ji"}},"key":"1D732"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Psi"}},"key":"1D733"},{"category":"Lu","mappings":{"default":{"default":"negrita cursiva mayúscula Omega"}},"key":"1D734"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva alfa"}},"key":"1D736"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva beta"}},"key":"1D737"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva gamma"}},"key":"1D738"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva delta"}},"key":"1D739"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva épsilon"}},"key":"1D73A"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva zeta"}},"key":"1D73B"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva eta"}},"key":"1D73C"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva theta"}},"key":"1D73D"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva iota"}},"key":"1D73E"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva kappa"}},"key":"1D73F"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva lambda"}},"key":"1D740"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva mi"}},"key":"1D741"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva ni"}},"key":"1D742"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva xi"}},"key":"1D743"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva ómicron"}},"key":"1D744"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva pi"}},"key":"1D745"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva rho"}},"key":"1D746"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva final sigma"}},"key":"1D747"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva sigma"}},"key":"1D748"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva tau"}},"key":"1D749"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva ípsilon"}},"key":"1D74A"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva phi"}},"key":"1D74B"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva ji"}},"key":"1D74C"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva psi"}},"key":"1D74D"},{"category":"Ll","mappings":{"default":{"default":"negrita cursiva omega"}},"key":"1D74E"}]
