[{"locale":"fr"},{"key":"cosh","mappings":{"default":{"default":"cosinus hyperbolique"}},"category":"Hyperbolic","names":["cosh"]},{"key":"coth","mappings":{"default":{"default":"cotangente hyperbolique"}},"category":"Hyperbolic","names":["coth"]},{"key":"csch","mappings":{"default":{"default":"cosécante hyperbolique"}},"category":"Hyperbolic","names":["csch"]},{"key":"sech","mappings":{"default":{"default":"sécante hyperbolique"}},"category":"Hyperbolic","names":["sech"]},{"key":"sinh","mappings":{"default":{"default":"sinus hyperbolique"}},"category":"Hyperbolic","names":["sinh"]},{"key":"tanh","mappings":{"default":{"default":"tangente hyperbolique"}},"category":"Hyperbolic","names":["tanh"]}]
