[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠁"}},"key":"1D538"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠃"}},"key":"1D539"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠉"}},"key":"2102"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠙"}},"key":"1D53B"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠑"}},"key":"1D53C"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠋"}},"key":"1D53D"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠛"}},"key":"1D53E"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠓"}},"key":"210D"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠊"}},"key":"1D540"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠚"}},"key":"1D541"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠅"}},"key":"1D542"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠇"}},"key":"1D543"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠍"}},"key":"1D544"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠝"}},"key":"2115"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠕"}},"key":"1D546"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠏"}},"key":"2119"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠟"}},"key":"211A"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠗"}},"key":"211D"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠎"}},"key":"1D54A"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠞"}},"key":"1D54B"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠥"}},"key":"1D54C"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠧"}},"key":"1D54D"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠺"}},"key":"1D54E"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠭"}},"key":"1D54F"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠽"}},"key":"1D550"},{"category":"Lu","mappings":{"default":{"default":"⠈⠠⠵"}},"key":"2124"},{"category":"Ll","mappings":{"default":{"default":"⠈⠁"}},"key":"1D552"},{"category":"Ll","mappings":{"default":{"default":"⠈⠃"}},"key":"1D553"},{"category":"Ll","mappings":{"default":{"default":"⠈⠉"}},"key":"1D554"},{"category":"Ll","mappings":{"default":{"default":"⠈⠙"}},"key":"1D555"},{"category":"Ll","mappings":{"default":{"default":"⠈⠑"}},"key":"1D556"},{"category":"Ll","mappings":{"default":{"default":"⠈⠋"}},"key":"1D557"},{"category":"Ll","mappings":{"default":{"default":"⠈⠛"}},"key":"1D558"},{"category":"Ll","mappings":{"default":{"default":"⠈⠓"}},"key":"1D559"},{"category":"Ll","mappings":{"default":{"default":"⠈⠊"}},"key":"1D55A"},{"category":"Ll","mappings":{"default":{"default":"⠈⠚"}},"key":"1D55B"},{"category":"Ll","mappings":{"default":{"default":"⠈⠅"}},"key":"1D55C"},{"category":"Ll","mappings":{"default":{"default":"⠈⠇"}},"key":"1D55D"},{"category":"Ll","mappings":{"default":{"default":"⠈⠍"}},"key":"1D55E"},{"category":"Ll","mappings":{"default":{"default":"⠈⠝"}},"key":"1D55F"},{"category":"Ll","mappings":{"default":{"default":"⠈⠕"}},"key":"1D560"},{"category":"Ll","mappings":{"default":{"default":"⠈⠏"}},"key":"1D561"},{"category":"Ll","mappings":{"default":{"default":"⠈⠟"}},"key":"1D562"},{"category":"Ll","mappings":{"default":{"default":"⠈⠗"}},"key":"1D563"},{"category":"Ll","mappings":{"default":{"default":"⠈⠎"}},"key":"1D564"},{"category":"Ll","mappings":{"default":{"default":"⠈⠞"}},"key":"1D565"},{"category":"Ll","mappings":{"default":{"default":"⠈⠥"}},"key":"1D566"},{"category":"Ll","mappings":{"default":{"default":"⠈⠧"}},"key":"1D567"},{"category":"Ll","mappings":{"default":{"default":"⠈⠺"}},"key":"1D568"},{"category":"Ll","mappings":{"default":{"default":"⠈⠭"}},"key":"1D569"},{"category":"Ll","mappings":{"default":{"default":"⠈⠽"}},"key":"1D56A"},{"category":"Ll","mappings":{"default":{"default":"⠈⠵"}},"key":"1D56B"}]
