[{"locale":"fr"},{"key":"1D6E2","mappings":{"default":{"default":"Alpha majuscule en italique"}},"category":"Lu"},{"key":"1D6E3","mappings":{"default":{"default":"Bêta majuscule en italique"}},"category":"Lu"},{"key":"1D6E4","mappings":{"default":{"default":"Gamma majuscule en italique"}},"category":"Lu"},{"key":"1D6E5","mappings":{"default":{"default":"Delta majuscule en italique"}},"category":"Lu"},{"key":"1D6E6","mappings":{"default":{"default":"Epsilon majuscule en italique"}},"category":"Lu"},{"key":"1D6E7","mappings":{"default":{"default":"Dzêta majuscule en italique"}},"category":"Lu"},{"key":"1D6E8","mappings":{"default":{"default":"Êta majuscule en italique"}},"category":"Lu"},{"key":"1D6E9","mappings":{"default":{"default":"Thêta majuscule en italique"}},"category":"Lu"},{"key":"1D6EA","mappings":{"default":{"default":"Iota majuscule en italique"}},"category":"Lu"},{"key":"1D6EB","mappings":{"default":{"default":"Kappa majuscule en italique"}},"category":"Lu"},{"key":"1D6EC","mappings":{"default":{"default":"Lambda majuscule en italique"}},"category":"Lu"},{"key":"1D6ED","mappings":{"default":{"default":"Mu majuscule en italique"}},"category":"Lu"},{"key":"1D6EE","mappings":{"default":{"default":"Nu majuscule en italique"}},"category":"Lu"},{"key":"1D6EF","mappings":{"default":{"default":"Xi majuscule en italique"}},"category":"Lu"},{"key":"1D6F0","mappings":{"default":{"default":"Omicron majuscule en italique"}},"category":"Lu"},{"key":"1D6F1","mappings":{"default":{"default":"Pi majuscule en italique"}},"category":"Lu"},{"key":"1D6F2","mappings":{"default":{"default":"Rhô majuscule en italique"}},"category":"Lu"},{"key":"1D6F4","mappings":{"default":{"default":"Sigma majuscule en italique"}},"category":"Lu"},{"key":"1D6F5","mappings":{"default":{"default":"Tau majuscule en italique"}},"category":"Lu"},{"key":"1D6F6","mappings":{"default":{"default":"Upsilon majuscule en italique"}},"category":"Lu"},{"key":"1D6F7","mappings":{"default":{"default":"Phi majuscule en italique"}},"category":"Lu"},{"key":"1D6F8","mappings":{"default":{"default":"Chi majuscule en italique"}},"category":"Lu"},{"key":"1D6F9","mappings":{"default":{"default":"Psi majuscule en italique"}},"category":"Lu"},{"key":"1D6FA","mappings":{"default":{"default":"Oméga majuscule en italique"}},"category":"Lu"},{"key":"1D6FC","mappings":{"default":{"default":"alpha en italique"}},"category":"Ll"},{"key":"1D6FD","mappings":{"default":{"default":"bêta en italique"}},"category":"Ll"},{"key":"1D6FE","mappings":{"default":{"default":"gamma en italique"}},"category":"Ll"},{"key":"1D6FF","mappings":{"default":{"default":"delta en italique"}},"category":"Ll"},{"key":"1D700","mappings":{"default":{"default":"epsilon en italique"}},"category":"Ll"},{"key":"1D701","mappings":{"default":{"default":"dzêta en italique"}},"category":"Ll"},{"key":"1D702","mappings":{"default":{"default":"êta en italique"}},"category":"Ll"},{"key":"1D703","mappings":{"default":{"default":"thêta en italique"}},"category":"Ll"},{"key":"1D704","mappings":{"default":{"default":"iota en italique"}},"category":"Ll"},{"key":"1D705","mappings":{"default":{"default":"kappa en italique"}},"category":"Ll"},{"key":"1D706","mappings":{"default":{"default":"lambda en italique"}},"category":"Ll"},{"key":"1D707","mappings":{"default":{"default":"mu en italique"}},"category":"Ll"},{"key":"1D708","mappings":{"default":{"default":"nu en italique"}},"category":"Ll"},{"key":"1D709","mappings":{"default":{"default":"xi en italique"}},"category":"Ll"},{"key":"1D70A","mappings":{"default":{"default":"omicron en italique"}},"category":"Ll"},{"key":"1D70B","mappings":{"default":{"default":"pi en italique"}},"category":"Ll"},{"key":"1D70C","mappings":{"default":{"default":"rhô en italique"}},"category":"Ll"},{"key":"1D70D","mappings":{"default":{"default":"mathématique italique sigma final"}},"category":"Ll"},{"key":"1D70E","mappings":{"default":{"default":"sigma en italique"}},"category":"Ll"},{"key":"1D70F","mappings":{"default":{"default":"tau en italique"}},"category":"Ll"},{"key":"1D710","mappings":{"default":{"default":"upsilon en italique"}},"category":"Ll"},{"key":"1D711","mappings":{"default":{"default":"phi en italique"}},"category":"Ll"},{"key":"1D712","mappings":{"default":{"default":"chi en italique"}},"category":"Ll"},{"key":"1D713","mappings":{"default":{"default":"psi en italique"}},"category":"Ll"},{"key":"1D714","mappings":{"default":{"default":"oméga en italique"}},"category":"Ll"}]
