[{"locale":"nemeth"},{"category":"Ll","key":"03B1","mappings":{"default":{"default":"⠨⠁"}}},{"category":"Ll","key":"03B2","mappings":{"default":{"default":"⠨⠃"}}},{"category":"Ll","key":"03B3","mappings":{"default":{"default":"⠨⠛"}}},{"category":"Ll","key":"03B4","mappings":{"default":{"default":"⠨⠙"}}},{"category":"Ll","key":"03B5","mappings":{"default":{"default":"⠨⠑"}}},{"category":"Ll","key":"03B6","mappings":{"default":{"default":"⠨⠱"}}},{"category":"Ll","key":"03B7","mappings":{"default":{"default":"⠨⠦"}}},{"category":"Ll","key":"03B8","mappings":{"default":{"default":"⠨⠹"}}},{"category":"Ll","key":"03B9","mappings":{"default":{"default":"⠨⠊"}}},{"category":"Ll","key":"03BA","mappings":{"default":{"default":"⠨⠅"}}},{"category":"Ll","key":"03BB","mappings":{"default":{"default":"⠨⠇"}}},{"category":"Ll","key":"03BC","mappings":{"default":{"default":"⠨⠍"}}},{"category":"Ll","key":"03BD","mappings":{"default":{"default":"⠨⠝"}}},{"category":"Ll","key":"03BE","mappings":{"default":{"default":"⠨⠭"}}},{"category":"Ll","key":"03BF","mappings":{"default":{"default":"⠨⠕"}}},{"category":"Ll","key":"03C0","mappings":{"default":{"default":"⠨⠏"}}},{"category":"Ll","key":"03C1","mappings":{"default":{"default":"⠨⠗"}}},{"category":"Ll","key":"03C2","mappings":{"default":{"default":"⠨⠒"}}},{"category":"Ll","key":"03C3","mappings":{"default":{"default":"⠨⠎"}}},{"category":"Ll","key":"03C4","mappings":{"default":{"default":"⠨⠞"}}},{"category":"Ll","key":"03C5","mappings":{"default":{"default":"⠨⠥"}}},{"category":"Ll","key":"03C6","mappings":{"default":{"default":"⠨⠋"}}},{"category":"Ll","key":"03C7","mappings":{"default":{"default":"⠨⠯"}}},{"category":"Ll","key":"03C8","mappings":{"default":{"default":"⠨⠓"}}},{"category":"Ll","key":"03C9","mappings":{"default":{"default":"⠨⠕"}}}]
