"""
MaRDMO: A plugin for RDMO to document and search 
mathematical models, algorithms, and interdisciplinary 
workflows.

Modules:
- models: document mathematical models
- algorithms: document algorithms
- workflows: document interdisciplinary workflows
- publication: document publications for models, algorithms, and workflows
- search: search models, algorithms, and workflows
"""

__title__ = 'MaRDMO'
__version__ = '0.3.4'
__author__ = 'Marco Reidelbach'
__email__ = 'reidelbach@zib.de'
__license__ = 'Apache-2.0'

VERSION = __version__
