[{"locale":"nemeth"},{"category":"","mappings":{"default":{"default":"⠇⠃"}},"key":"lb","names":["lb","lb."]},{"category":"","mappings":{"default":{"default":"⠇⠞"}},"key":"LT","names":["LT","L.T."]},{"category":"","mappings":{"default":{"default":"⠕⠵"}},"key":"oz","names":["oz","oz."]},{"key":"µg","names":["µg","mcg"],"mappings":{"default":{"default":"⠨⠍⠛"}}},{"category":"","mappings":{"default":{"default":"⠛⠗"}},"key":"gr","names":["g","gr"]},{"category":"","mappings":{"default":{"default":"⠅⠛"}},"key":"kg","names":["kg"]},{"category":"","mappings":{"default":{"default":"⠍⠉⠛"}},"key":"mcg","names":["mg","µg"]},{"category":"","mappings":{"default":{"default":"⠍⠛"}},"key":"mg","names":["mg"]},{"category":"","mappings":{"default":{"default":"⠞"}},"key":"t","names":["t","T"]}]
