[{"locale":"fr"},{"key":"1D670","mappings":{"default":{"default":"A majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D671","mappings":{"default":{"default":"B majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D672","mappings":{"default":{"default":"C majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D673","mappings":{"default":{"default":"D majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D674","mappings":{"default":{"default":"E majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D675","mappings":{"default":{"default":"F majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D676","mappings":{"default":{"default":"G majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D677","mappings":{"default":{"default":"H majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D678","mappings":{"default":{"default":"I majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D679","mappings":{"default":{"default":"J majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D67A","mappings":{"default":{"default":"K majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D67B","mappings":{"default":{"default":"L majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D67C","mappings":{"default":{"default":"M majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D67D","mappings":{"default":{"default":"N majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D67E","mappings":{"default":{"default":"O majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D67F","mappings":{"default":{"default":"P majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D680","mappings":{"default":{"default":"Q majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D681","mappings":{"default":{"default":"R majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D682","mappings":{"default":{"default":"S majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D683","mappings":{"default":{"default":"T majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D684","mappings":{"default":{"default":"U majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D685","mappings":{"default":{"default":"V majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D686","mappings":{"default":{"default":"W majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D687","mappings":{"default":{"default":"X majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D688","mappings":{"default":{"default":"Y majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D689","mappings":{"default":{"default":"Z majuscule en chasse fixe"}},"category":"Lu"},{"key":"1D68A","mappings":{"default":{"default":"a en chasse fixe"}},"category":"Ll"},{"key":"1D68B","mappings":{"default":{"default":"b en chasse fixe"}},"category":"Ll"},{"key":"1D68C","mappings":{"default":{"default":"c en chasse fixe"}},"category":"Ll"},{"key":"1D68D","mappings":{"default":{"default":"d en chasse fixe"}},"category":"Ll"},{"key":"1D68E","mappings":{"default":{"default":"e en chasse fixe"}},"category":"Ll"},{"key":"1D68F","mappings":{"default":{"default":"f en chasse fixe"}},"category":"Ll"},{"key":"1D690","mappings":{"default":{"default":"g en chasse fixe"}},"category":"Ll"},{"key":"1D691","mappings":{"default":{"default":"h en chasse fixe"}},"category":"Ll"},{"key":"1D692","mappings":{"default":{"default":"i en chasse fixe"}},"category":"Ll"},{"key":"1D693","mappings":{"default":{"default":"j en chasse fixe"}},"category":"Ll"},{"key":"1D694","mappings":{"default":{"default":"k en chasse fixe"}},"category":"Ll"},{"key":"1D695","mappings":{"default":{"default":"l en chasse fixe"}},"category":"Ll"},{"key":"1D696","mappings":{"default":{"default":"m en chasse fixe"}},"category":"Ll"},{"key":"1D697","mappings":{"default":{"default":"n en chasse fixe"}},"category":"Ll"},{"key":"1D698","mappings":{"default":{"default":"o en chasse fixe"}},"category":"Ll"},{"key":"1D699","mappings":{"default":{"default":"p en chasse fixe"}},"category":"Ll"},{"key":"1D69A","mappings":{"default":{"default":"q en chasse fixe"}},"category":"Ll"},{"key":"1D69B","mappings":{"default":{"default":"r en chasse fixe"}},"category":"Ll"},{"key":"1D69C","mappings":{"default":{"default":"s en chasse fixe"}},"category":"Ll"},{"key":"1D69D","mappings":{"default":{"default":"t en chasse fixe"}},"category":"Ll"},{"key":"1D69E","mappings":{"default":{"default":"u en chasse fixe"}},"category":"Ll"},{"key":"1D69F","mappings":{"default":{"default":"v en chasse fixe"}},"category":"Ll"},{"key":"1D6A0","mappings":{"default":{"default":"w en chasse fixe"}},"category":"Ll"},{"key":"1D6A1","mappings":{"default":{"default":"x en chasse fixe"}},"category":"Ll"},{"key":"1D6A2","mappings":{"default":{"default":"y en chasse fixe"}},"category":"Ll"},{"key":"1D6A3","mappings":{"default":{"default":"z en chasse fixe"}},"category":"Ll"}]
