[{"locale":"es"},{"key":"kt","names":["kt","kt."],"mappings":{"default":{"default":"nudo"}},"category":"speed"},{"key":"mph","names":["mph"],"mappings":{"default":{"default":"millas por hora"}},"category":"speed"},{"key":"rpm","names":["rpm"],"mappings":{"default":{"default":"revoluciones por minuto"}},"category":"speed"},{"key":"kmh","names":["kmh"],"mappings":{"default":{"default":"kilómetros por hora"}},"category":"speed"}]
