[{"locale":"fr"},{"key":"1D71C","mappings":{"default":{"default":"Alpha majuscule en italique gras"}},"category":"Lu"},{"key":"1D71D","mappings":{"default":{"default":"Bêta majuscule en italique gras"}},"category":"Lu"},{"key":"1D71E","mappings":{"default":{"default":"Gamma majuscule en italique gras"}},"category":"Lu"},{"key":"1D71F","mappings":{"default":{"default":"Delta majuscule en italique gras"}},"category":"Lu"},{"key":"1D720","mappings":{"default":{"default":"Epsilon majuscule en italique gras"}},"category":"Lu"},{"key":"1D721","mappings":{"default":{"default":"Dzêta majuscule en italique gras"}},"category":"Lu"},{"key":"1D722","mappings":{"default":{"default":"Êta majuscule en italique gras"}},"category":"Lu"},{"key":"1D723","mappings":{"default":{"default":"Thêta majuscule en italique gras"}},"category":"Lu"},{"key":"1D724","mappings":{"default":{"default":"Iota majuscule en italique gras"}},"category":"Lu"},{"key":"1D725","mappings":{"default":{"default":"Kappa majuscule en italique gras"}},"category":"Lu"},{"key":"1D726","mappings":{"default":{"default":"Lambda majuscule en italique gras"}},"category":"Lu"},{"key":"1D727","mappings":{"default":{"default":"Mu majuscule en italique gras"}},"category":"Lu"},{"key":"1D728","mappings":{"default":{"default":"Nu majuscule en italique gras"}},"category":"Lu"},{"key":"1D729","mappings":{"default":{"default":"Xi majuscule en italique gras"}},"category":"Lu"},{"key":"1D72A","mappings":{"default":{"default":"Omicron majuscule en italique gras"}},"category":"Lu"},{"key":"1D72B","mappings":{"default":{"default":"Pi majuscule en italique gras"}},"category":"Lu"},{"key":"1D72C","mappings":{"default":{"default":"Rhô majuscule en italique gras"}},"category":"Lu"},{"key":"1D72E","mappings":{"default":{"default":"Sigma majuscule en italique gras"}},"category":"Lu"},{"key":"1D72F","mappings":{"default":{"default":"Tau majuscule en italique gras"}},"category":"Lu"},{"key":"1D730","mappings":{"default":{"default":"Upsilon majuscule en italique gras"}},"category":"Lu"},{"key":"1D731","mappings":{"default":{"default":"Phi majuscule en italique gras"}},"category":"Lu"},{"key":"1D732","mappings":{"default":{"default":"Chi majuscule en italique gras"}},"category":"Lu"},{"key":"1D733","mappings":{"default":{"default":"Psi majuscule en italique gras"}},"category":"Lu"},{"key":"1D734","mappings":{"default":{"default":"Oméga majuscule en italique gras"}},"category":"Lu"},{"key":"1D736","mappings":{"default":{"default":"alpha en italique gras"}},"category":"Ll"},{"key":"1D737","mappings":{"default":{"default":"bêta en italique gras"}},"category":"Ll"},{"key":"1D738","mappings":{"default":{"default":"gamma en italique gras"}},"category":"Ll"},{"key":"1D739","mappings":{"default":{"default":"delta en italique gras"}},"category":"Ll"},{"key":"1D73A","mappings":{"default":{"default":"epsilon en italique gras"}},"category":"Ll"},{"key":"1D73B","mappings":{"default":{"default":"dzêta en italique gras"}},"category":"Ll"},{"key":"1D73C","mappings":{"default":{"default":"êta en italique gras"}},"category":"Ll"},{"key":"1D73D","mappings":{"default":{"default":"thêta en italique gras"}},"category":"Ll"},{"key":"1D73E","mappings":{"default":{"default":"iota en italique gras"}},"category":"Ll"},{"key":"1D73F","mappings":{"default":{"default":"kappa en italique gras"}},"category":"Ll"},{"key":"1D740","mappings":{"default":{"default":"lambda en italique gras"}},"category":"Ll"},{"key":"1D741","mappings":{"default":{"default":"mu en italique gras"}},"category":"Ll"},{"key":"1D742","mappings":{"default":{"default":"nu en italique gras"}},"category":"Ll"},{"key":"1D743","mappings":{"default":{"default":"xi en italique gras"}},"category":"Ll"},{"key":"1D744","mappings":{"default":{"default":"omicron en italique gras"}},"category":"Ll"},{"key":"1D745","mappings":{"default":{"default":"pi en italique gras"}},"category":"Ll"},{"key":"1D746","mappings":{"default":{"default":"rhô en italique gras"}},"category":"Ll"},{"key":"1D747","mappings":{"default":{"default":"mathématique italique grasse sigma final"}},"category":"Ll"},{"key":"1D748","mappings":{"default":{"default":"sigma en italique gras"}},"category":"Ll"},{"key":"1D749","mappings":{"default":{"default":"tau en italique gras"}},"category":"Ll"},{"key":"1D74A","mappings":{"default":{"default":"upsilon en italique gras"}},"category":"Ll"},{"key":"1D74B","mappings":{"default":{"default":"phi en italique gras"}},"category":"Ll"},{"key":"1D74C","mappings":{"default":{"default":"chi en italique gras"}},"category":"Ll"},{"key":"1D74D","mappings":{"default":{"default":"psi en italique gras"}},"category":"Ll"},{"key":"1D74E","mappings":{"default":{"default":"oméga en italique gras"}},"category":"Ll"}]
