[{"locale":"fr"},{"key":"1E09","mappings":{"default":{"default":"c cédille et accent aigu"}},"category":"Ll"},{"key":"1E15","mappings":{"default":{"default":"e macron et accent grave"}},"category":"Ll"},{"key":"1E17","mappings":{"default":{"default":"e macron et accent aigu"}},"category":"Ll"},{"key":"1E1D","mappings":{"default":{"default":"e cédille et brève"}},"category":"Ll"},{"key":"1E2F","mappings":{"default":{"default":"i tréma et accent aigu"}},"category":"Ll"},{"key":"1E39","mappings":{"default":{"default":"l point souscrit et macron"}},"category":"Ll"},{"key":"1E4D","mappings":{"default":{"default":"o tilde et accent aigu"}},"category":"Ll"},{"key":"1E4F","mappings":{"default":{"default":"o tilde et tréma"}},"category":"Ll"},{"key":"1E51","mappings":{"default":{"default":"o macron et accent grave"}},"category":"Ll"},{"key":"1E53","mappings":{"default":{"default":"o macron et accent aigu"}},"category":"Ll"},{"key":"1E5D","mappings":{"default":{"default":"r point souscrit et macron"}},"category":"Ll"},{"key":"1E65","mappings":{"default":{"default":"s accent aigu et point en chef"}},"category":"Ll"},{"key":"1E67","mappings":{"default":{"default":"s caron et point en chef"}},"category":"Ll"},{"key":"1E69","mappings":{"default":{"default":"s point souscrit et point en chef"}},"category":"Ll"},{"key":"1E79","mappings":{"default":{"default":"u tilde et accent aigu"}},"category":"Ll"},{"key":"1E7B","mappings":{"default":{"default":"u macron et tréma"}},"category":"Ll"},{"key":"1EA5","mappings":{"default":{"default":"a accent circonflexe et accent aigu"}},"category":"Ll"},{"key":"1EA7","mappings":{"default":{"default":"a accent circonflexe et accent grave"}},"category":"Ll"},{"key":"1EA9","mappings":{"default":{"default":"a accent circonflexe et crochet en chef"}},"category":"Ll"},{"key":"1EAB","mappings":{"default":{"default":"a accent circonflexe et tilde"}},"category":"Ll"},{"key":"1EAD","mappings":{"default":{"default":"a accent circonflexe et point souscrit"}},"category":"Ll"},{"key":"1EAF","mappings":{"default":{"default":"a brève et accent aigu"}},"category":"Ll"},{"key":"1EB1","mappings":{"default":{"default":"a brève et accent grave"}},"category":"Ll"},{"key":"1EB3","mappings":{"default":{"default":"a brève et crochet en chef"}},"category":"Ll"},{"key":"1EB5","mappings":{"default":{"default":"a brève et tilde"}},"category":"Ll"},{"key":"1EB7","mappings":{"default":{"default":"a brève et point souscrit"}},"category":"Ll"},{"key":"1EBF","mappings":{"default":{"default":"e accent circonflexe et accent aigu"}},"category":"Ll"},{"key":"1EC1","mappings":{"default":{"default":"e accent circonflexe et accent grave"}},"category":"Ll"},{"key":"1EC3","mappings":{"default":{"default":"e accent circonflexe et crochet en chef"}},"category":"Ll"},{"key":"1EC5","mappings":{"default":{"default":"e accent circonflexe et tilde"}},"category":"Ll"},{"key":"1EC7","mappings":{"default":{"default":"e accent circonflexe et point souscrit"}},"category":"Ll"},{"key":"1ED1","mappings":{"default":{"default":"o accent circonflexe et accent aigu"}},"category":"Ll"},{"key":"1ED3","mappings":{"default":{"default":"o accent circonflexe et accent grave"}},"category":"Ll"},{"key":"1ED5","mappings":{"default":{"default":"o accent circonflexe et crochet en chef"}},"category":"Ll"},{"key":"1ED7","mappings":{"default":{"default":"o accent circonflexe et tilde"}},"category":"Ll"},{"key":"1ED9","mappings":{"default":{"default":"o accent circonflexe et point souscrit"}},"category":"Ll"},{"key":"1EDB","mappings":{"default":{"default":"o cornu accent aigu"}},"category":"Ll"},{"key":"1EDD","mappings":{"default":{"default":"o cornu accent grave"}},"category":"Ll"},{"key":"1EDF","mappings":{"default":{"default":"o cornu crochet en chef"}},"category":"Ll"},{"key":"1EE1","mappings":{"default":{"default":"o cornu tilde"}},"category":"Ll"},{"key":"1EE3","mappings":{"default":{"default":"o cornu point souscrit"}},"category":"Ll"},{"key":"1EE9","mappings":{"default":{"default":"u cornu accent aigu"}},"category":"Ll"},{"key":"1EEB","mappings":{"default":{"default":"u cornu accent grave"}},"category":"Ll"},{"key":"1EED","mappings":{"default":{"default":"u cornu crochet en chef"}},"category":"Ll"},{"key":"1EEF","mappings":{"default":{"default":"u cornu tilde"}},"category":"Ll"},{"key":"1EF1","mappings":{"default":{"default":"u cornu point souscrit"}},"category":"Ll"}]
