[{"locale":"nemeth"},{"category":"Trigonometric","mappings":{"default":{"default":"⠉⠕⠎⠀"}},"key":"cos","names":["cos","cosine"]},{"category":"Trigonometric","mappings":{"default":{"default":"⠉⠕⠞⠀"}},"key":"cot","names":["cot"]},{"category":"Trigonometric","mappings":{"default":{"default":"⠉⠎⠉⠀"}},"key":"csc","names":["csc"]},{"category":"Trigonometric","mappings":{"default":{"default":"⠎⠑⠉⠀"}},"key":"sec","names":["sec"]},{"category":"Trigonometric","mappings":{"default":{"default":"⠎⠊⠝⠀"}},"key":"sin","names":["sin","sine"]},{"category":"Trigonometric","mappings":{"default":{"default":"⠞⠁⠝⠀"}},"key":"tan","names":["tan"]},{"category":"Cyclometric","mappings":{"default":{"default":"⠁⠗⠉⠉⠕⠎⠀"}},"key":"arccos","names":["arccos"]},{"category":"Cyclometric","mappings":{"default":{"default":"⠁⠗⠉⠀⠉⠕⠞⠀"}},"key":"arccot","names":["arccot"]},{"category":"Cyclometric","mappings":{"default":{"default":"⠁⠗⠉⠀⠉⠎⠉⠀"}},"key":"arccsc","names":["arccsc"]},{"category":"Cyclometric","mappings":{"default":{"default":"⠁⠗⠉⠀⠎⠑⠉⠀"}},"key":"arcsec","names":["arcsec"]},{"category":"Cyclometric","mappings":{"default":{"default":"⠁⠗⠉⠀⠎⠊⠝⠀"}},"key":"arcsin","names":["arcsin"]},{"category":"Cyclometric","mappings":{"default":{"default":"⠁⠗⠉⠀⠞⠁⠝⠀"}},"key":"arctan","names":["arctan"]}]
