[{"locale":"fr"},{"key":"1D6A8","mappings":{"default":{"default":"Alpha majuscule en gras"}},"category":"Lu"},{"key":"1D6A9","mappings":{"default":{"default":"Bêta majuscule en gras"}},"category":"Lu"},{"key":"1D6AA","mappings":{"default":{"default":"Gamma majuscule en gras"}},"category":"Lu"},{"key":"1D6AB","mappings":{"default":{"default":"Delta majuscule en gras"}},"category":"Lu"},{"key":"1D6AC","mappings":{"default":{"default":"Epsilon majuscule en gras"}},"category":"Lu"},{"key":"1D6AD","mappings":{"default":{"default":"Dzêta majuscule en gras"}},"category":"Lu"},{"key":"1D6AE","mappings":{"default":{"default":"Êta majuscule en gras"}},"category":"Lu"},{"key":"1D6AF","mappings":{"default":{"default":"Thêta majuscule en gras"}},"category":"Lu"},{"key":"1D6B0","mappings":{"default":{"default":"Iota majuscule en gras"}},"category":"Lu"},{"key":"1D6B1","mappings":{"default":{"default":"Kappa majuscule en gras"}},"category":"Lu"},{"key":"1D6B2","mappings":{"default":{"default":"Lambda majuscule en gras"}},"category":"Lu"},{"key":"1D6B3","mappings":{"default":{"default":"Mu majuscule en gras"}},"category":"Lu"},{"key":"1D6B4","mappings":{"default":{"default":"Nu majuscule en gras"}},"category":"Lu"},{"key":"1D6B5","mappings":{"default":{"default":"Xi majuscule en gras"}},"category":"Lu"},{"key":"1D6B6","mappings":{"default":{"default":"Omicron majuscule en gras"}},"category":"Lu"},{"key":"1D6B7","mappings":{"default":{"default":"Pi majuscule en gras"}},"category":"Lu"},{"key":"1D6B8","mappings":{"default":{"default":"Rhô majuscule en gras"}},"category":"Lu"},{"key":"1D6BA","mappings":{"default":{"default":"Sigma majuscule en gras"}},"category":"Lu"},{"key":"1D6BB","mappings":{"default":{"default":"Tau majuscule en gras"}},"category":"Lu"},{"key":"1D6BC","mappings":{"default":{"default":"Upsilon majuscule en gras"}},"category":"Lu"},{"key":"1D6BD","mappings":{"default":{"default":"Phi majuscule en gras"}},"category":"Lu"},{"key":"1D6BE","mappings":{"default":{"default":"Chi majuscule en gras"}},"category":"Lu"},{"key":"1D6BF","mappings":{"default":{"default":"Psi majuscule en gras"}},"category":"Lu"},{"key":"1D6C0","mappings":{"default":{"default":"Oméga majuscule en gras"}},"category":"Lu"},{"key":"1D6C2","mappings":{"default":{"default":"alpha en gras"}},"category":"Ll"},{"key":"1D6C3","mappings":{"default":{"default":"bêta en gras"}},"category":"Ll"},{"key":"1D6C4","mappings":{"default":{"default":"gamma en gras"}},"category":"Ll"},{"key":"1D6C5","mappings":{"default":{"default":"delta en gras"}},"category":"Ll"},{"key":"1D6C6","mappings":{"default":{"default":"epsilon en gras"}},"category":"Ll"},{"key":"1D6C7","mappings":{"default":{"default":"dzêta en gras"}},"category":"Ll"},{"key":"1D6C8","mappings":{"default":{"default":"êta en gras"}},"category":"Ll"},{"key":"1D6C9","mappings":{"default":{"default":"thêta en gras"}},"category":"Ll"},{"key":"1D6CA","mappings":{"default":{"default":"iota en gras"}},"category":"Ll"},{"key":"1D6CB","mappings":{"default":{"default":"kappa en gras"}},"category":"Ll"},{"key":"1D6CC","mappings":{"default":{"default":"lambda en gras"}},"category":"Ll"},{"key":"1D6CD","mappings":{"default":{"default":"mu en gras"}},"category":"Ll"},{"key":"1D6CE","mappings":{"default":{"default":"nu en gras"}},"category":"Ll"},{"key":"1D6CF","mappings":{"default":{"default":"xi en gras"}},"category":"Ll"},{"key":"1D6D0","mappings":{"default":{"default":"omicron en gras"}},"category":"Ll"},{"key":"1D6D1","mappings":{"default":{"default":"pi en gras"}},"category":"Ll"},{"key":"1D6D2","mappings":{"default":{"default":"rhô en gras"}},"category":"Ll"},{"key":"1D6D3","mappings":{"default":{"default":"mathématique grasse sigma final"}},"category":"Ll"},{"key":"1D6D4","mappings":{"default":{"default":"sigma en gras"}},"category":"Ll"},{"key":"1D6D5","mappings":{"default":{"default":"tau en gras"}},"category":"Ll"},{"key":"1D6D6","mappings":{"default":{"default":"upsilon en gras"}},"category":"Ll"},{"key":"1D6D7","mappings":{"default":{"default":"phi en gras"}},"category":"Ll"},{"key":"1D6D8","mappings":{"default":{"default":"chi en gras"}},"category":"Ll"},{"key":"1D6D9","mappings":{"default":{"default":"psi en gras"}},"category":"Ll"},{"key":"1D6DA","mappings":{"default":{"default":"oméga en gras"}},"category":"Ll"}]
