[{"locale":"nemeth"},{"category":"Length","mappings":{"default":{"default":"⠍⠍"}},"key":"mm","names":["mm"]},{"category":"Length","mappings":{"default":{"default":"⠉⠍"}},"key":"cm","names":["cm"]},{"category":"Length","mappings":{"default":{"default":"⠍"}},"key":"m","names":["m"]},{"category":"Length","mappings":{"default":{"default":"⠅⠍"}},"key":"km","names":["km"]},{"category":"Length","mappings":{"default":{"default":"⠋⠞"}},"key":"ft","names":["ft","ft."]},{"category":"Length","mappings":{"default":{"default":"⠊⠝"}},"key":"in","names":["in","in."]},{"category":"Length","mappings":{"default":{"default":"⠍⠊"}},"key":"mi","names":["mi","mi."]},{"category":"Length","mappings":{"default":{"default":"⠽⠙"}},"key":"yd","names":["yd","yd."]},{"category":"","mappings":{"default":{"default":"⠝⠲⠍⠸⠲"}},"key":"n.m.","names":["n.m."]}]
