[{"locale":"fr"},{"key":"bbl","mappings":{"default":{"default":"barils","singular":"baril","dual":""}},"category":"volume","names":["bbl.","bbl"]},{"key":"gal","mappings":{"default":{"default":"gallons","singular":"gallon","dual":""}},"category":"volume","names":["gal","gal."]},{"key":"pt","mappings":{"default":{"default":"pintes","singular":"pinte","dual":""}},"category":"volume","names":["pt","pt."]},{"key":"qt","mappings":{"default":{"default":"quarts","singular":"quart","dual":""}},"category":"volume","names":["qt","qt."]},{"key":"tbsp","mappings":{"default":{"default":"cuillères de table","singular":"cuillèe de table","dual":""}},"category":"volume","names":["tbsp","tbsp."]},{"key":"tsp","mappings":{"default":{"default":"cuillèes à thé","singular":"cuillère à thé","dual":""}},"category":"volume","names":["tsp","tsp."]},{"key":"l","mappings":{"default":{"default":"litres","singular":"litre","dual":""}},"category":"volume","names":["l"]}]
