
{% extends 'core/page.html' %}
{% load i18n %}
{% load static %}

{% block page %}
    <div align='center'>
        <br><br><br><br><br><br><br>
        <figure>
            <img src="{% static 'MaRDMO/images/MaRDMOLogo.png' %}" alt="Logo of MaRDMO Plugin">
        </figure>
        <br><br><br>
        {% if ids %}
            <p style="color:Black;font-size:40px;;font-weight:bold">Entities added to MathAlgoDB!</p>
            {% for key, value in ids.items %}
                {% if forloop.counter == 1 %}
                    <br>
                    <p style="color:Black;font-size:20px;;font-weight:bold">Links to Entities:</p>
                {% endif %}
	            <p style="color:grey;font-size:20px;;font-weight:bold"><a href="{{mathalgodb_uri}}object/{{value}}" style="color:dodgerblue;">{{key}}</a>&#x1F517;
            {% endfor %}
        {% else %}
            <p style="color:Black;font-size:40px;;font-weight:bold">No new Entities added to MathAlgoDB!</p>
            <p style="color:Black;font-size:20px;;font-weight:bold">(If you defined new Relations, they were added successfully.)</p>
            <br>
            <p style="color:Black;font-size:20px;;font-weight:bold">Checkout <a href="{{mathalgodb_uri}}" style="color:dodgerblue;">MathAlgoDB</a>&#x1F517;</p>
        {% endif %}
    </p>
    </div>
    <!-- Attribution Section -->
    <div align='center' style="margin-top: 50px; font-size: 14px; color: grey;">
        <p>MaRDMO Logo by <a href="https://www.mardi4nfdi.de/about/mission" target="_blank" style="color: grey;">MaRDI</a>, licensed under <a href="https://creativecommons.org/licenses/by-nc-nd/4.0/" target="_blank" style="color: grey;">CC BY-NC-ND 4.0</a>.</p>
    </div>
    {% endblock %}
