[{"locale":"fr"},{"key":"2135","mappings":{"default":{"default":"alef"}},"category":"Lo"},{"key":"2136","mappings":{"default":{"default":"bèt"}},"category":"Lo"},{"key":"2137","mappings":{"default":{"default":"guimel"}},"category":"Lo"},{"key":"2138","mappings":{"default":{"default":"dalèt"}},"category":"Lo"}]
