[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠁"}},"key":"1D504"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠃"}},"key":"1D505"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠉"}},"key":"212D"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠙"}},"key":"1D507"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠑"}},"key":"1D508"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠋"}},"key":"1D509"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠛"}},"key":"1D50A"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠓"}},"key":"210C"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠊"}},"key":"2111"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠚"}},"key":"1D50D"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠅"}},"key":"1D50E"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠇"}},"key":"1D50F"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠍"}},"key":"1D510"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠝"}},"key":"1D511"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠕"}},"key":"1D512"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠏"}},"key":"1D513"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠟"}},"key":"1D514"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠗"}},"key":"211C"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠎"}},"key":"1D516"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠞"}},"key":"1D517"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠥"}},"key":"1D518"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠧"}},"key":"1D519"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠺"}},"key":"1D51A"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠭"}},"key":"1D51B"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠽"}},"key":"1D51C"},{"category":"Lu","mappings":{"default":{"default":"⠸⠠⠵"}},"key":"2128"},{"category":"Ll","mappings":{"default":{"default":"⠸⠁"}},"key":"1D51E"},{"category":"Ll","mappings":{"default":{"default":"⠸⠃"}},"key":"1D51F"},{"category":"Ll","mappings":{"default":{"default":"⠸⠉"}},"key":"1D520"},{"category":"Ll","mappings":{"default":{"default":"⠸⠙"}},"key":"1D521"},{"category":"Ll","mappings":{"default":{"default":"⠸⠑"}},"key":"1D522"},{"category":"Ll","mappings":{"default":{"default":"⠸⠋"}},"key":"1D523"},{"category":"Ll","mappings":{"default":{"default":"⠸⠛"}},"key":"1D524"},{"category":"Ll","mappings":{"default":{"default":"⠸⠓"}},"key":"1D525"},{"category":"Ll","mappings":{"default":{"default":"⠸⠊"}},"key":"1D526"},{"category":"Ll","mappings":{"default":{"default":"⠸⠚"}},"key":"1D527"},{"category":"Ll","mappings":{"default":{"default":"⠸⠅"}},"key":"1D528"},{"category":"Ll","mappings":{"default":{"default":"⠸⠇"}},"key":"1D529"},{"category":"Ll","mappings":{"default":{"default":"⠸⠍"}},"key":"1D52A"},{"category":"Ll","mappings":{"default":{"default":"⠸⠝"}},"key":"1D52B"},{"category":"Ll","mappings":{"default":{"default":"⠸⠕"}},"key":"1D52C"},{"category":"Ll","mappings":{"default":{"default":"⠸⠏"}},"key":"1D52D"},{"category":"Ll","mappings":{"default":{"default":"⠸⠟"}},"key":"1D52E"},{"category":"Ll","mappings":{"default":{"default":"⠸⠗"}},"key":"1D52F"},{"category":"Ll","mappings":{"default":{"default":"⠸⠎"}},"key":"1D530"},{"category":"Ll","mappings":{"default":{"default":"⠸⠞"}},"key":"1D531"},{"category":"Ll","mappings":{"default":{"default":"⠸⠥"}},"key":"1D532"},{"category":"Ll","mappings":{"default":{"default":"⠸⠧"}},"key":"1D533"},{"category":"Ll","mappings":{"default":{"default":"⠸⠺"}},"key":"1D534"},{"category":"Ll","mappings":{"default":{"default":"⠸⠭"}},"key":"1D535"},{"category":"Ll","mappings":{"default":{"default":"⠸⠽"}},"key":"1D536"},{"category":"Ll","mappings":{"default":{"default":"⠸⠵"}},"key":"1D537"}]
