[{"locale":"nemeth"},{"category":"Logarithm","mappings":{"default":{"default":"⠇⠕⠏⠀"}},"key":"log","names":["log"]},{"category":"Logarithm","mappings":{"default":{"default":"⠇⠝⠀"}},"key":"ln","names":["ln"]},{"category":"Logarithm","mappings":{"default":{"default":"⠇⠛"}},"key":"lg","names":["lg"]},{"category":"Elementary","mappings":{"default":{"default":"⠑⠭⠏"}},"key":"exp","names":["exp","expt"]},{"category":"Elementary","mappings":{"default":{"default":"⠛⠉⠙"}},"key":"gcd","names":["gcd"]},{"category":"Elementary","mappings":{"default":{"default":"⠇⠉⠍"}},"key":"lcm","names":["lcm"]},{"category":"Complex","mappings":{"default":{"default":"⠁⠗⠛⠀"}},"key":"arg","names":["arg"]},{"category":"Complex","mappings":{"default":{"default":"⠊⠍"}},"key":"im","names":["im"]},{"category":"Complex","mappings":{"default":{"default":"⠗⠑"}},"key":"re","names":["re"]},{"category":"Limits","mappings":{"default":{"default":"⠊⠝⠋⠀"}},"key":"inf","names":["inf"]},{"category":"Limits","mappings":{"default":{"default":"⠇⠊⠍"}},"key":"lim","names":["lim"]},{"category":"Limits","mappings":{"default":{"default":"⠇⠊⠍⠊⠝⠀⠋"}},"key":"liminf","names":["lim inf","liminf"]},{"category":"Limits","mappings":{"default":{"default":"⠇⠊⠍⠎⠥⠏"}},"key":"limsup","names":["lim sup","limsup"]},{"category":"Limits","mappings":{"default":{"default":"⠍⠁⠭⠀"}},"key":"max","names":["max"]},{"category":"Limits","mappings":{"default":{"default":"⠍⠊⠝⠀"}},"key":"min","names":["min"]},{"category":"Limits","mappings":{"default":{"default":"⠎⠥⠏"}},"key":"sup","names":["sup"]},{"category":"Limits","mappings":{"default":{"default":"⠊⠝⠚⠇⠊⠍"}},"key":"injlim","names":["injlim","inj lim"]},{"category":"Limits","mappings":{"default":{"default":"⠏⠗⠕⠚⠇⠊⠍"}},"key":"projlim","names":["projlim","proj lim"]},{"category":"Elementary","mappings":{"default":{"default":"⠍⠕⠙"}},"key":"mod","names":["mod"]},{"category":"Probability","mappings":{"default":{"default":"⠠⠏⠗"}},"key":"Pr","names":["Pr"]}]
