[{"locale":"fr"},{"key":"1E08","mappings":{"default":{"default":"C cédille et accent aigu majuscule"}},"category":"Lu"},{"key":"1E14","mappings":{"default":{"default":"E macron et accent grave majuscule"}},"category":"Lu"},{"key":"1E16","mappings":{"default":{"default":"E macron et accent aigu majuscule"}},"category":"Lu"},{"key":"1E1C","mappings":{"default":{"default":"E cédille et brève majuscule"}},"category":"Lu"},{"key":"1E2E","mappings":{"default":{"default":"I tréma et accent aigu majuscule"}},"category":"Lu"},{"key":"1E38","mappings":{"default":{"default":"L point souscrit et macron majuscule"}},"category":"Lu"},{"key":"1E4C","mappings":{"default":{"default":"O tilde et accent aigu majuscule"}},"category":"Lu"},{"key":"1E4E","mappings":{"default":{"default":"O tilde et tréma majuscule"}},"category":"Lu"},{"key":"1E50","mappings":{"default":{"default":"O macron et accent grave majuscule"}},"category":"Lu"},{"key":"1E52","mappings":{"default":{"default":"O macron et accent aigu majuscule"}},"category":"Lu"},{"key":"1E5C","mappings":{"default":{"default":"R point souscrit et macron majuscule"}},"category":"Lu"},{"key":"1E64","mappings":{"default":{"default":"S accent aigu et point en chef majuscule"}},"category":"Lu"},{"key":"1E66","mappings":{"default":{"default":"S caron et point en chef majuscule"}},"category":"Lu"},{"key":"1E68","mappings":{"default":{"default":"S point souscrit et point en chef majuscule"}},"category":"Lu"},{"key":"1E78","mappings":{"default":{"default":"U tilde et accent aigu majuscule"}},"category":"Lu"},{"key":"1E7A","mappings":{"default":{"default":"U macron et tréma majuscule"}},"category":"Lu"},{"key":"1EA4","mappings":{"default":{"default":"A accent circonflexe et accent aigu majuscule"}},"category":"Lu"},{"key":"1EA6","mappings":{"default":{"default":"A accent circonflexe et accent grave majuscule"}},"category":"Lu"},{"key":"1EA8","mappings":{"default":{"default":"A accent circonflexe et crochet en chef majuscule"}},"category":"Lu"},{"key":"1EAA","mappings":{"default":{"default":"A accent circonflexe et tilde majuscule"}},"category":"Lu"},{"key":"1EAC","mappings":{"default":{"default":"A accent circonflexe et point souscrit majuscule"}},"category":"Lu"},{"key":"1EAE","mappings":{"default":{"default":"A brève et accent aigu majuscule"}},"category":"Lu"},{"key":"1EB0","mappings":{"default":{"default":"A brève et accent grave majuscule"}},"category":"Lu"},{"key":"1EB2","mappings":{"default":{"default":"A brève et crochet en chef majuscule"}},"category":"Lu"},{"key":"1EB4","mappings":{"default":{"default":"A brève et tilde majuscule"}},"category":"Lu"},{"key":"1EB6","mappings":{"default":{"default":"A brève et point souscrit majuscule"}},"category":"Lu"},{"key":"1EBE","mappings":{"default":{"default":"E accent circonflexe et accent aigu majuscule"}},"category":"Lu"},{"key":"1EC0","mappings":{"default":{"default":"E accent circonflexe et accent grave majuscule"}},"category":"Lu"},{"key":"1EC2","mappings":{"default":{"default":"E accent circonflexe et crochet en chef majuscule"}},"category":"Lu"},{"key":"1EC4","mappings":{"default":{"default":"E accent circonflexe et tilde majuscule"}},"category":"Lu"},{"key":"1EC6","mappings":{"default":{"default":"E accent circonflexe et point souscrit majuscule"}},"category":"Lu"},{"key":"1ED0","mappings":{"default":{"default":"O accent circonflexe et accent aigu majuscule"}},"category":"Lu"},{"key":"1ED2","mappings":{"default":{"default":"O accent circonflexe et accent grave majuscule"}},"category":"Lu"},{"key":"1ED4","mappings":{"default":{"default":"O accent circonflexe et crochet en chef majuscule"}},"category":"Lu"},{"key":"1ED6","mappings":{"default":{"default":"O accent circonflexe et tilde majuscule"}},"category":"Lu"},{"key":"1ED8","mappings":{"default":{"default":"O accent circonflexe et point souscrit majuscule"}},"category":"Lu"},{"key":"1EDA","mappings":{"default":{"default":"O cornu accent aigu majuscule"}},"category":"Lu"},{"key":"1EDC","mappings":{"default":{"default":"O cornu accent grave majuscule"}},"category":"Lu"},{"key":"1EDE","mappings":{"default":{"default":"O cornu crochet en chef majuscule"}},"category":"Lu"},{"key":"1EE0","mappings":{"default":{"default":"O cornu tilde majuscule"}},"category":"Lu"},{"key":"1EE2","mappings":{"default":{"default":"O cornu point souscrit majuscule"}},"category":"Lu"},{"key":"1EE8","mappings":{"default":{"default":"U cornu accent aigu majuscule"}},"category":"Lu"},{"key":"1EEA","mappings":{"default":{"default":"U cornu accent grave majuscule"}},"category":"Lu"},{"key":"1EEC","mappings":{"default":{"default":"U cornu crochet en chef majuscule"}},"category":"Lu"},{"key":"1EEE","mappings":{"default":{"default":"U cornu tilde majuscule"}},"category":"Lu"},{"key":"1EF0","mappings":{"default":{"default":"U cornu point souscrit majuscule"}},"category":"Lu"}]
