[{"locale":"en"},{"category":"length","mappings":{"default":{"default":"millimeter"}},"key":"mm","names":["mm"]},{"category":"length","mappings":{"default":{"default":"centimeter"}},"key":"cm","names":["cm"]},{"category":"length","mappings":{"default":{"default":"meter"}},"key":"m","names":["m"]},{"category":"length","mappings":{"default":{"default":"kilometer"}},"key":"km","names":["km"]},{"category":"length","mappings":{"default":{"default":"foot"}},"key":"ft","names":["ft","ft."]},{"category":"length","mappings":{"default":{"default":"inch"}},"key":"in","names":["in","in."]},{"category":"length","mappings":{"default":{"default":"mile"}},"key":"mi","names":["mi","mi."]},{"category":"length","mappings":{"default":{"default":"yard"}},"key":"yd","names":["yd","yd."]},{"category":"length","mappings":{"default":{"default":"nautical mile"}},"key":"n.m.","names":["n.m."]}]
