[{"locale":"nemeth"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠁"}},"key":"1D6E2"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠃"}},"key":"1D6E3"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠛"}},"key":"1D6E4"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠙"}},"key":"1D6E5"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠑"}},"key":"1D6E6"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠱"}},"key":"1D6E7"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠣"}},"key":"1D6E8"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠹"}},"key":"1D6E9"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠊"}},"key":"1D6EA"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠅"}},"key":"1D6EB"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠇"}},"key":"1D6EC"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠍"}},"key":"1D6ED"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠝"}},"key":"1D6EE"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠭"}},"key":"1D6EF"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠕"}},"key":"1D6F0"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠏"}},"key":"1D6F1"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠗"}},"key":"1D6F2"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠎"}},"key":"1D6F4"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠥"}},"key":"1D6F5"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠥"}},"key":"1D6F6"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠋"}},"key":"1D6F7"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠯"}},"key":"1D6F8"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠫"}},"key":"1D6F9"},{"category":"Lu","mappings":{"default":{"default":"⠨⠨⠠⠺"}},"key":"1D6FA"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠁"}},"key":"1D6FC"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠃"}},"key":"1D6FD"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠛"}},"key":"1D6FE"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠙"}},"key":"1D6FF"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠑"}},"key":"1D700"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠱"}},"key":"1D701"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠦"}},"key":"1D702"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠹"}},"key":"1D703"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠊"}},"key":"1D704"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠅"}},"key":"1D705"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠇"}},"key":"1D706"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠍"}},"key":"1D707"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠝"}},"key":"1D708"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠭"}},"key":"1D709"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠕"}},"key":"1D70A"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠏"}},"key":"1D70B"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠗"}},"key":"1D70C"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠒"}},"key":"1D70D"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠎"}},"key":"1D70E"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠞"}},"key":"1D70F"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠥"}},"key":"1D710"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠋"}},"key":"1D711"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠯"}},"key":"1D712"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠓"}},"key":"1D713"},{"category":"Ll","mappings":{"default":{"default":"⠨⠨⠕"}},"key":"1D714"}]
