[{"locale":"nemeth"},{"category":"","mappings":{"default":{"default":"⠅⠞"}},"key":"kt","names":["kt","kt."]},{"category":"","mappings":{"default":{"default":"⠍⠏⠓"}},"key":"mph","names":["mph"]},{"category":"","mappings":{"default":{"default":"⠗⠏⠍"}},"key":"rpm","names":["rpm"]},{"category":"","mappings":{"default":{"default":"⠅⠍⠓"}},"key":"kmh","names":["kmh"]}]
