[{"locale":"nemeth"},{"category":"Hyperbolic","mappings":{"default":{"default":"⠉⠕⠎⠓⠀"}},"key":"cosh","names":["cosh"]},{"category":"Hyperbolic","mappings":{"default":{"default":"⠉⠕⠞⠓⠀"}},"key":"coth","names":["coth"]},{"category":"Hyperbolic","mappings":{"default":{"default":"⠉⠎⠉⠓⠀"}},"key":"csch","names":["csch"]},{"category":"Hyperbolic","mappings":{"default":{"default":"⠎⠑⠉⠓⠀"}},"key":"sech","names":["sech"]},{"category":"Hyperbolic","mappings":{"default":{"default":"⠎⠊⠝⠓⠀"}},"key":"sinh","names":["sinh"]},{"category":"Hyperbolic","mappings":{"default":{"default":"⠞⠁⠕⠓⠀"}},"key":"tanh","names":["tanh"]},{"category":"Area","mappings":{"default":{"default":"⠁⠗⠉⠀⠕⠎⠓"}},"key":"arcosh","names":["arcosh","arccosh"]},{"category":"Area","mappings":{"default":{"default":"⠁⠗⠉⠀⠕⠞⠓"}},"key":"arcoth","names":["arcoth","arccoth"]},{"category":"Area","mappings":{"default":{"default":"⠁⠗⠉⠀⠎⠉⠓"}},"key":"arcsch","names":["arcsch","arccsch"]},{"category":"Area","mappings":{"default":{"default":"⠁⠗⠎⠑⠉⠓⠀"}},"key":"arsech","names":["arsech","arcsech"]},{"category":"Area","mappings":{"default":{"default":"⠁⠗⠎⠊⠝⠓⠀"}},"key":"arsinh","names":["arsinh","arcsinh"]},{"category":"Area","mappings":{"default":{"default":"⠁⠗⠞⠁⠕⠓⠀"}},"key":"artanh","names":["artanh","arctanh"]}]
