[{"locale":"fr"},{"key":"cos","mappings":{"default":{"default":"cosinus"}},"category":"Trigonometric","names":["cos","cosine"]},{"key":"cot","mappings":{"default":{"default":"cotangente"}},"category":"Trigonometric","names":["cot"]},{"key":"csc","mappings":{"default":{"default":"cosécante"}},"category":"Trigonometric","names":["csc"]},{"key":"sec","mappings":{"default":{"default":"sécante"}},"category":"Trigonometric","names":["sec"]},{"key":"sin","mappings":{"default":{"default":"sinus"}},"category":"Trigonometric","names":["sin","sine"]},{"key":"tan","mappings":{"default":{"default":"tangente"}},"category":"Trigonometric","names":["tan"]}]
