[{"locale":"fr"},{"key":"1D4D0","mappings":{"default":{"default":"A majuscule en script gras"}},"category":"Lu"},{"key":"1D4D1","mappings":{"default":{"default":"B majuscule en script gras"}},"category":"Lu"},{"key":"1D4D2","mappings":{"default":{"default":"C majuscule en script gras"}},"category":"Lu"},{"key":"1D4D3","mappings":{"default":{"default":"D majuscule en script gras"}},"category":"Lu"},{"key":"1D4D4","mappings":{"default":{"default":"E majuscule en script gras"}},"category":"Lu"},{"key":"1D4D5","mappings":{"default":{"default":"F majuscule en script gras"}},"category":"Lu"},{"key":"1D4D6","mappings":{"default":{"default":"G majuscule en script gras"}},"category":"Lu"},{"key":"1D4D7","mappings":{"default":{"default":"H majuscule en script gras"}},"category":"Lu"},{"key":"1D4D8","mappings":{"default":{"default":"I majuscule en script gras"}},"category":"Lu"},{"key":"1D4D9","mappings":{"default":{"default":"J majuscule en script gras"}},"category":"Lu"},{"key":"1D4DA","mappings":{"default":{"default":"K majuscule en script gras"}},"category":"Lu"},{"key":"1D4DB","mappings":{"default":{"default":"L majuscule en script gras"}},"category":"Lu"},{"key":"1D4DC","mappings":{"default":{"default":"M majuscule en script gras"}},"category":"Lu"},{"key":"1D4DD","mappings":{"default":{"default":"N majuscule en script gras"}},"category":"Lu"},{"key":"1D4DE","mappings":{"default":{"default":"O majuscule en script gras"}},"category":"Lu"},{"key":"1D4DF","mappings":{"default":{"default":"P majuscule en script gras"}},"category":"Lu"},{"key":"1D4E0","mappings":{"default":{"default":"Q majuscule en script gras"}},"category":"Lu"},{"key":"1D4E1","mappings":{"default":{"default":"R majuscule en script gras"}},"category":"Lu"},{"key":"1D4E2","mappings":{"default":{"default":"S majuscule en script gras"}},"category":"Lu"},{"key":"1D4E3","mappings":{"default":{"default":"T majuscule en script gras"}},"category":"Lu"},{"key":"1D4E4","mappings":{"default":{"default":"U majuscule en script gras"}},"category":"Lu"},{"key":"1D4E5","mappings":{"default":{"default":"V majuscule en script gras"}},"category":"Lu"},{"key":"1D4E6","mappings":{"default":{"default":"W majuscule en script gras"}},"category":"Lu"},{"key":"1D4E7","mappings":{"default":{"default":"X majuscule en script gras"}},"category":"Lu"},{"key":"1D4E8","mappings":{"default":{"default":"Y majuscule en script gras"}},"category":"Lu"},{"key":"1D4E9","mappings":{"default":{"default":"Z majuscule en script gras"}},"category":"Lu"},{"key":"1D4EA","mappings":{"default":{"default":"a en script gras"}},"category":"Ll"},{"key":"1D4EB","mappings":{"default":{"default":"b en script gras"}},"category":"Ll"},{"key":"1D4EC","mappings":{"default":{"default":"c en script gras"}},"category":"Ll"},{"key":"1D4ED","mappings":{"default":{"default":"d en script gras"}},"category":"Ll"},{"key":"1D4EE","mappings":{"default":{"default":"e en script gras"}},"category":"Ll"},{"key":"1D4EF","mappings":{"default":{"default":"f en script gras"}},"category":"Ll"},{"key":"1D4F0","mappings":{"default":{"default":"g en script gras"}},"category":"Ll"},{"key":"1D4F1","mappings":{"default":{"default":"h en script gras"}},"category":"Ll"},{"key":"1D4F2","mappings":{"default":{"default":"i en script gras"}},"category":"Ll"},{"key":"1D4F3","mappings":{"default":{"default":"j en script gras"}},"category":"Ll"},{"key":"1D4F4","mappings":{"default":{"default":"k en script gras"}},"category":"Ll"},{"key":"1D4F5","mappings":{"default":{"default":"l en script gras"}},"category":"Ll"},{"key":"1D4F6","mappings":{"default":{"default":"m en script gras"}},"category":"Ll"},{"key":"1D4F7","mappings":{"default":{"default":"n en script gras"}},"category":"Ll"},{"key":"1D4F8","mappings":{"default":{"default":"o en script gras"}},"category":"Ll"},{"key":"1D4F9","mappings":{"default":{"default":"p en script gras"}},"category":"Ll"},{"key":"1D4FA","mappings":{"default":{"default":"q en script gras"}},"category":"Ll"},{"key":"1D4FB","mappings":{"default":{"default":"r en script gras"}},"category":"Ll"},{"key":"1D4FC","mappings":{"default":{"default":"s en script gras"}},"category":"Ll"},{"key":"1D4FD","mappings":{"default":{"default":"t en script gras"}},"category":"Ll"},{"key":"1D4FE","mappings":{"default":{"default":"u en script gras"}},"category":"Ll"},{"key":"1D4FF","mappings":{"default":{"default":"v en script gras"}},"category":"Ll"},{"key":"1D500","mappings":{"default":{"default":"w en script gras"}},"category":"Ll"},{"key":"1D501","mappings":{"default":{"default":"x en script gras"}},"category":"Ll"},{"key":"1D502","mappings":{"default":{"default":"y en script gras"}},"category":"Ll"},{"key":"1D503","mappings":{"default":{"default":"z en script gras"}},"category":"Ll"}]
