[{"locale":"fr"},{"key":"0041","mappings":{"default":{"default":"A majuscule"}},"category":"Lu"},{"key":"0042","mappings":{"default":{"default":"B majuscule"}},"category":"Lu"},{"key":"0043","mappings":{"default":{"default":"C majuscule"}},"category":"Lu"},{"key":"0044","mappings":{"default":{"default":"D majuscule"}},"category":"Lu"},{"key":"0045","mappings":{"default":{"default":"E majuscule"}},"category":"Lu"},{"key":"0046","mappings":{"default":{"default":"F majuscule"}},"category":"Lu"},{"key":"0047","mappings":{"default":{"default":"G majuscule"}},"category":"Lu"},{"key":"0048","mappings":{"default":{"default":"H majuscule"}},"category":"Lu"},{"key":"0049","mappings":{"default":{"default":"I majuscule"}},"category":"Lu"},{"key":"004A","mappings":{"default":{"default":"J majuscule"}},"category":"Lu"},{"key":"004B","mappings":{"default":{"default":"K majuscule"}},"category":"Lu"},{"key":"004C","mappings":{"default":{"default":"L majuscule"}},"category":"Lu"},{"key":"004D","mappings":{"default":{"default":"M majuscule"}},"category":"Lu"},{"key":"004E","mappings":{"default":{"default":"N majuscule"}},"category":"Lu"},{"key":"004F","mappings":{"default":{"default":"O majuscule"}},"category":"Lu"},{"key":"0050","mappings":{"default":{"default":"P majuscule"}},"category":"Lu"},{"key":"0051","mappings":{"default":{"default":"Q majuscule"}},"category":"Lu"},{"key":"0052","mappings":{"default":{"default":"R majuscule"}},"category":"Lu"},{"key":"0053","mappings":{"default":{"default":"S majuscule"}},"category":"Lu"},{"key":"0054","mappings":{"default":{"default":"T majuscule"}},"category":"Lu"},{"key":"0055","mappings":{"default":{"default":"U majuscule"}},"category":"Lu"},{"key":"0056","mappings":{"default":{"default":"V majuscule"}},"category":"Lu"},{"key":"0057","mappings":{"default":{"default":"W majuscule"}},"category":"Lu"},{"key":"0058","mappings":{"default":{"default":"X majuscule"}},"category":"Lu"},{"key":"0059","mappings":{"default":{"default":"Y majuscule"}},"category":"Lu"},{"key":"005A","mappings":{"default":{"default":"Z majuscule"}},"category":"Lu"}]
