[{"locale":"es"},{"key":"doz","names":["doz","doz.","dz","dz."],"mappings":{"default":{"default":"docena"}},"category":"other"},{"key":"sq","names":["sq","sq."],"mappings":{"default":{"default":"al cuadrado"}},"category":"other"},{"key":"ha","names":["ha"],"mappings":{"default":{"default":"hectarea"}},"category":"other"}]
