[{"locale":"nemeth"},{"category":"Ll","key":"0061","mappings":{"default":{"default":"⠁"}}},{"category":"Ll","key":"0062","mappings":{"default":{"default":"⠃"}}},{"category":"Ll","key":"0063","mappings":{"default":{"default":"⠉"}}},{"category":"Ll","key":"0064","mappings":{"default":{"default":"⠙"}}},{"category":"Ll","key":"0065","mappings":{"default":{"default":"⠑"}}},{"category":"Ll","key":"0066","mappings":{"default":{"default":"⠋"}}},{"category":"Ll","key":"0067","mappings":{"default":{"default":"⠛"}}},{"category":"Ll","key":"0068","mappings":{"default":{"default":"⠓"}}},{"category":"Ll","key":"0069","mappings":{"default":{"default":"⠊"}}},{"category":"Ll","key":"006A","mappings":{"default":{"default":"⠚"}}},{"category":"Ll","key":"006B","mappings":{"default":{"default":"⠅"}}},{"category":"Ll","key":"006C","mappings":{"default":{"default":"⠇"}}},{"category":"Ll","key":"006D","mappings":{"default":{"default":"⠍"}}},{"category":"Ll","key":"006E","mappings":{"default":{"default":"⠝"}}},{"category":"Ll","key":"006F","mappings":{"default":{"default":"⠕"}}},{"category":"Ll","key":"0070","mappings":{"default":{"default":"⠏"}}},{"category":"Ll","key":"0071","mappings":{"default":{"default":"⠟"}}},{"category":"Ll","key":"0072","mappings":{"default":{"default":"⠗"}}},{"category":"Ll","key":"0073","mappings":{"default":{"default":"⠎"}}},{"category":"Ll","key":"0074","mappings":{"default":{"default":"⠞"}}},{"category":"Ll","key":"0075","mappings":{"default":{"default":"⠥"}}},{"category":"Ll","key":"0076","mappings":{"default":{"default":"⠧"}}},{"category":"Ll","key":"0077","mappings":{"default":{"default":"⠺"}}},{"category":"Ll","key":"0078","mappings":{"default":{"default":"⠭"}}},{"category":"Ll","key":"0079","mappings":{"default":{"default":"⠽"}}},{"category":"Ll","key":"007A","mappings":{"default":{"default":"⠵"}}},{"category":"Ll","key":"FF41","mappings":{"default":{"default":"⠁"}}},{"category":"Ll","key":"FF42","mappings":{"default":{"default":"⠃"}}},{"category":"Ll","key":"FF43","mappings":{"default":{"default":"⠉"}}},{"category":"Ll","key":"FF44","mappings":{"default":{"default":"⠙"}}},{"category":"Ll","key":"FF45","mappings":{"default":{"default":"⠑"}}},{"category":"Ll","key":"FF46","mappings":{"default":{"default":"⠋"}}},{"category":"Ll","key":"FF47","mappings":{"default":{"default":"⠛"}}},{"category":"Ll","key":"FF48","mappings":{"default":{"default":"⠓"}}},{"category":"Ll","key":"FF49","mappings":{"default":{"default":"⠊"}}},{"category":"Ll","key":"FF4A","mappings":{"default":{"default":"⠚"}}},{"category":"Ll","key":"FF4B","mappings":{"default":{"default":"⠅"}}},{"category":"Ll","key":"FF4C","mappings":{"default":{"default":"⠇"}}},{"category":"Ll","key":"FF4D","mappings":{"default":{"default":"⠍"}}},{"category":"Ll","key":"FF4E","mappings":{"default":{"default":"⠝"}}},{"category":"Ll","key":"FF4F","mappings":{"default":{"default":"⠕"}}},{"category":"Ll","key":"FF50","mappings":{"default":{"default":"⠏"}}},{"category":"Ll","key":"FF51","mappings":{"default":{"default":"⠟"}}},{"category":"Ll","key":"FF52","mappings":{"default":{"default":"⠗"}}},{"category":"Ll","key":"FF53","mappings":{"default":{"default":"⠎"}}},{"category":"Ll","key":"FF54","mappings":{"default":{"default":"⠞"}}},{"category":"Ll","key":"FF55","mappings":{"default":{"default":"⠥"}}},{"category":"Ll","key":"FF56","mappings":{"default":{"default":"⠧"}}},{"category":"Ll","key":"FF57","mappings":{"default":{"default":"⠺"}}},{"category":"Ll","key":"FF58","mappings":{"default":{"default":"⠭"}}},{"category":"Ll","key":"FF59","mappings":{"default":{"default":"⠽"}}},{"category":"Ll","key":"FF5A","mappings":{"default":{"default":"⠵"}}}]
