[{"locale":"fr"},{"key":"1D468","mappings":{"default":{"default":"A majuscule en italique gras"}},"category":"Lu"},{"key":"1D469","mappings":{"default":{"default":"B majuscule en italique gras"}},"category":"Lu"},{"key":"1D46A","mappings":{"default":{"default":"C majuscule en italique gras"}},"category":"Lu"},{"key":"1D46B","mappings":{"default":{"default":"D majuscule en italique gras"}},"category":"Lu"},{"key":"1D46C","mappings":{"default":{"default":"E majuscule en italique gras"}},"category":"Lu"},{"key":"1D46D","mappings":{"default":{"default":"F majuscule en italique gras"}},"category":"Lu"},{"key":"1D46E","mappings":{"default":{"default":"G majuscule en italique gras"}},"category":"Lu"},{"key":"1D46F","mappings":{"default":{"default":"H majuscule en italique gras"}},"category":"Lu"},{"key":"1D470","mappings":{"default":{"default":"I majuscule en italique gras"}},"category":"Lu"},{"key":"1D471","mappings":{"default":{"default":"J majuscule en italique gras"}},"category":"Lu"},{"key":"1D472","mappings":{"default":{"default":"K majuscule en italique gras"}},"category":"Lu"},{"key":"1D473","mappings":{"default":{"default":"L majuscule en italique gras"}},"category":"Lu"},{"key":"1D474","mappings":{"default":{"default":"M majuscule en italique gras"}},"category":"Lu"},{"key":"1D475","mappings":{"default":{"default":"N majuscule en italique gras"}},"category":"Lu"},{"key":"1D476","mappings":{"default":{"default":"O majuscule en italique gras"}},"category":"Lu"},{"key":"1D477","mappings":{"default":{"default":"P majuscule en italique gras"}},"category":"Lu"},{"key":"1D478","mappings":{"default":{"default":"Q majuscule en italique gras"}},"category":"Lu"},{"key":"1D479","mappings":{"default":{"default":"R majuscule en italique gras"}},"category":"Lu"},{"key":"1D47A","mappings":{"default":{"default":"S majuscule en italique gras"}},"category":"Lu"},{"key":"1D47B","mappings":{"default":{"default":"T majuscule en italique gras"}},"category":"Lu"},{"key":"1D47C","mappings":{"default":{"default":"U majuscule en italique gras"}},"category":"Lu"},{"key":"1D47D","mappings":{"default":{"default":"V majuscule en italique gras"}},"category":"Lu"},{"key":"1D47E","mappings":{"default":{"default":"W majuscule en italique gras"}},"category":"Lu"},{"key":"1D47F","mappings":{"default":{"default":"X majuscule en italique gras"}},"category":"Lu"},{"key":"1D480","mappings":{"default":{"default":"Y majuscule en italique gras"}},"category":"Lu"},{"key":"1D481","mappings":{"default":{"default":"Z majuscule en italique gras"}},"category":"Lu"},{"key":"1D482","mappings":{"default":{"default":"a en italique gras"}},"category":"Ll"},{"key":"1D483","mappings":{"default":{"default":"b en italique gras"}},"category":"Ll"},{"key":"1D484","mappings":{"default":{"default":"c en italique gras"}},"category":"Ll"},{"key":"1D485","mappings":{"default":{"default":"d en italique gras"}},"category":"Ll"},{"key":"1D486","mappings":{"default":{"default":"e en italique gras"}},"category":"Ll"},{"key":"1D487","mappings":{"default":{"default":"f en italique gras"}},"category":"Ll"},{"key":"1D488","mappings":{"default":{"default":"g en italique gras"}},"category":"Ll"},{"key":"1D489","mappings":{"default":{"default":"h en italique gras"}},"category":"Ll"},{"key":"1D48A","mappings":{"default":{"default":"i en italique gras"}},"category":"Ll"},{"key":"1D48B","mappings":{"default":{"default":"j en italique gras"}},"category":"Ll"},{"key":"1D48C","mappings":{"default":{"default":"k en italique gras"}},"category":"Ll"},{"key":"1D48D","mappings":{"default":{"default":"l en italique gras"}},"category":"Ll"},{"key":"1D48E","mappings":{"default":{"default":"m en italique gras"}},"category":"Ll"},{"key":"1D48F","mappings":{"default":{"default":"n en italique gras"}},"category":"Ll"},{"key":"1D490","mappings":{"default":{"default":"o en italique gras"}},"category":"Ll"},{"key":"1D491","mappings":{"default":{"default":"p en italique gras"}},"category":"Ll"},{"key":"1D492","mappings":{"default":{"default":"q en italique gras"}},"category":"Ll"},{"key":"1D493","mappings":{"default":{"default":"r en italique gras"}},"category":"Ll"},{"key":"1D494","mappings":{"default":{"default":"s en italique gras"}},"category":"Ll"},{"key":"1D495","mappings":{"default":{"default":"t en italique gras"}},"category":"Ll"},{"key":"1D496","mappings":{"default":{"default":"u en italique gras"}},"category":"Ll"},{"key":"1D497","mappings":{"default":{"default":"v en italique gras"}},"category":"Ll"},{"key":"1D498","mappings":{"default":{"default":"w en italique gras"}},"category":"Ll"},{"key":"1D499","mappings":{"default":{"default":"x en italique gras"}},"category":"Ll"},{"key":"1D49A","mappings":{"default":{"default":"y en italique gras"}},"category":"Ll"},{"key":"1D49B","mappings":{"default":{"default":"z en italique gras"}},"category":"Ll"}]
