[{"locale":"nemeth"},{"category":"time","mappings":{"default":{"default":"⠝⠎"}},"key":"ns","names":["ns"]},{"category":"time","mappings":{"default":{"default":"⠨⠍⠎"}},"key":"µs","names":["µs"]},{"category":"time","mappings":{"default":{"default":"⠍⠎"}},"key":"ms","names":["ms"]},{"category":"time","mappings":{"default":{"default":"⠎"}},"key":"s","names":["s"]},{"category":"time","mappings":{"default":{"default":"⠍⠊⠝⠀"}},"key":"min","names":["min"]},{"category":"time","mappings":{"default":{"default":"⠓"}},"key":"h","names":["h","hr"]}]
